/* notifier_freedesktop.c generated by valac 0.56.19, the Vala compiler
 * generated from notifier_freedesktop.vala, do not modify */

#include <glib-object.h>
#include "libdino.h"
#include <glib.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include <float.h>
#include <math.h>
#include "dino_i18n.h"
#include "xmpp-vala.h"
#include <cairo-gobject.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <gdk/gdk.h>
#include <gobject/gvaluecollector.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define DINO_UI_TYPE_FREE_DESKTOP_NOTIFIER (dino_ui_free_desktop_notifier_get_type ())
#define DINO_UI_FREE_DESKTOP_NOTIFIER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_UI_TYPE_FREE_DESKTOP_NOTIFIER, DinoUiFreeDesktopNotifier))
#define DINO_UI_FREE_DESKTOP_NOTIFIER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_UI_TYPE_FREE_DESKTOP_NOTIFIER, DinoUiFreeDesktopNotifierClass))
#define DINO_UI_IS_FREE_DESKTOP_NOTIFIER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_UI_TYPE_FREE_DESKTOP_NOTIFIER))
#define DINO_UI_IS_FREE_DESKTOP_NOTIFIER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_UI_TYPE_FREE_DESKTOP_NOTIFIER))
#define DINO_UI_FREE_DESKTOP_NOTIFIER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_UI_TYPE_FREE_DESKTOP_NOTIFIER, DinoUiFreeDesktopNotifierClass))

typedef struct _DinoUiFreeDesktopNotifier DinoUiFreeDesktopNotifier;
typedef struct _DinoUiFreeDesktopNotifierClass DinoUiFreeDesktopNotifierClass;
typedef struct _DinoUiFreeDesktopNotifierPrivate DinoUiFreeDesktopNotifierPrivate;

#define DINO_UI_FREE_DESKTOP_NOTIFIER_TYPE_LISTENER_FUNC_WRAPPER (dino_ui_free_desktop_notifier_listener_func_wrapper_get_type ())
#define DINO_UI_FREE_DESKTOP_NOTIFIER_LISTENER_FUNC_WRAPPER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_UI_FREE_DESKTOP_NOTIFIER_TYPE_LISTENER_FUNC_WRAPPER, DinoUiFreeDesktopNotifierListenerFuncWrapper))
#define DINO_UI_FREE_DESKTOP_NOTIFIER_LISTENER_FUNC_WRAPPER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_UI_FREE_DESKTOP_NOTIFIER_TYPE_LISTENER_FUNC_WRAPPER, DinoUiFreeDesktopNotifierListenerFuncWrapperClass))
#define DINO_UI_FREE_DESKTOP_NOTIFIER_IS_LISTENER_FUNC_WRAPPER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_UI_FREE_DESKTOP_NOTIFIER_TYPE_LISTENER_FUNC_WRAPPER))
#define DINO_UI_FREE_DESKTOP_NOTIFIER_IS_LISTENER_FUNC_WRAPPER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_UI_FREE_DESKTOP_NOTIFIER_TYPE_LISTENER_FUNC_WRAPPER))
#define DINO_UI_FREE_DESKTOP_NOTIFIER_LISTENER_FUNC_WRAPPER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_UI_FREE_DESKTOP_NOTIFIER_TYPE_LISTENER_FUNC_WRAPPER, DinoUiFreeDesktopNotifierListenerFuncWrapperClass))

typedef struct _DinoUiFreeDesktopNotifierListenerFuncWrapper DinoUiFreeDesktopNotifierListenerFuncWrapper;
typedef struct _DinoUiFreeDesktopNotifierListenerFuncWrapperClass DinoUiFreeDesktopNotifierListenerFuncWrapperClass;
enum  {
	DINO_UI_FREE_DESKTOP_NOTIFIER_0_PROPERTY,
	DINO_UI_FREE_DESKTOP_NOTIFIER_NUM_PROPERTIES
};
static GParamSpec* dino_ui_free_desktop_notifier_properties[DINO_UI_FREE_DESKTOP_NOTIFIER_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _DinoUiFreeDesktopNotifierListenerFuncWrapperPrivate DinoUiFreeDesktopNotifierListenerFuncWrapperPrivate;
typedef void (*DinoUiFreeDesktopNotifierListenerFunc) (gpointer user_data);
#define _dino_ui_free_desktop_notifier_listener_func_wrapper_unref0(var) ((var == NULL) ? NULL : (var = (dino_ui_free_desktop_notifier_listener_func_wrapper_unref (var), NULL)))
typedef struct _DinoUiFreeDesktopNotifierInitDbusNotificationsData DinoUiFreeDesktopNotifierInitDbusNotificationsData;
typedef struct _DinoUiFreeDesktopNotifierNotifyMessageData DinoUiFreeDesktopNotifierNotifyMessageData;
typedef struct _DinoUiFreeDesktopNotifierNotifyFileData DinoUiFreeDesktopNotifierNotifyFileData;
typedef struct _Block63Data Block63Data;
#define _g_variant_unref0(var) ((var == NULL) ? NULL : (var = (g_variant_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))
typedef struct _DinoUiFreeDesktopNotifierNotifyContentItemData DinoUiFreeDesktopNotifierNotifyContentItemData;
typedef struct _Block64Data Block64Data;
#define _xmpp_jid_unref0(var) ((var == NULL) ? NULL : (var = (xmpp_jid_unref (var), NULL)))
typedef struct _DinoUiFreeDesktopNotifierNotifyCallData DinoUiFreeDesktopNotifierNotifyCallData;
typedef struct _DinoUiFreeDesktopNotifierRetractCallNotificationData DinoUiFreeDesktopNotifierRetractCallNotificationData;
typedef struct _Block65Data Block65Data;
typedef struct _DinoUiFreeDesktopNotifierNotifySubscriptionRequestData DinoUiFreeDesktopNotifierNotifySubscriptionRequestData;
#define _dino_connection_manager_connection_error_unref0(var) ((var == NULL) ? NULL : (var = (dino_connection_manager_connection_error_unref (var), NULL)))
typedef struct _Block66Data Block66Data;
typedef struct _DinoUiFreeDesktopNotifierNotifyConnectionErrorData DinoUiFreeDesktopNotifierNotifyConnectionErrorData;
typedef struct _Block67Data Block67Data;
typedef struct _DinoUiFreeDesktopNotifierNotifyMucInviteData DinoUiFreeDesktopNotifierNotifyMucInviteData;
typedef struct _Block68Data Block68Data;
typedef struct _DinoUiFreeDesktopNotifierNotifyVoiceRequestData DinoUiFreeDesktopNotifierNotifyVoiceRequestData;
typedef struct _DinoUiFreeDesktopNotifierRetractContentItemNotificationsData DinoUiFreeDesktopNotifierRetractContentItemNotificationsData;
typedef struct _DinoUiFreeDesktopNotifierRetractConversationNotificationsData DinoUiFreeDesktopNotifierRetractConversationNotificationsData;

#define DINO_UI_TYPE_COMPAT_AVATAR_DRAWER (dino_ui_compat_avatar_drawer_get_type ())
#define DINO_UI_COMPAT_AVATAR_DRAWER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_UI_TYPE_COMPAT_AVATAR_DRAWER, DinoUiCompatAvatarDrawer))
#define DINO_UI_COMPAT_AVATAR_DRAWER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_UI_TYPE_COMPAT_AVATAR_DRAWER, DinoUiCompatAvatarDrawerClass))
#define DINO_UI_IS_COMPAT_AVATAR_DRAWER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_UI_TYPE_COMPAT_AVATAR_DRAWER))
#define DINO_UI_IS_COMPAT_AVATAR_DRAWER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_UI_TYPE_COMPAT_AVATAR_DRAWER))
#define DINO_UI_COMPAT_AVATAR_DRAWER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_UI_TYPE_COMPAT_AVATAR_DRAWER, DinoUiCompatAvatarDrawerClass))

typedef struct _DinoUiCompatAvatarDrawer DinoUiCompatAvatarDrawer;
typedef struct _DinoUiCompatAvatarDrawerClass DinoUiCompatAvatarDrawerClass;

#define DINO_UI_VIEW_MODEL_TYPE_AVATAR_PICTURE_MODEL (dino_ui_view_model_avatar_picture_model_get_type ())
#define DINO_UI_VIEW_MODEL_AVATAR_PICTURE_MODEL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_UI_VIEW_MODEL_TYPE_AVATAR_PICTURE_MODEL, DinoUiViewModelAvatarPictureModel))
#define DINO_UI_VIEW_MODEL_AVATAR_PICTURE_MODEL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_UI_VIEW_MODEL_TYPE_AVATAR_PICTURE_MODEL, DinoUiViewModelAvatarPictureModelClass))
#define DINO_UI_VIEW_MODEL_IS_AVATAR_PICTURE_MODEL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_UI_VIEW_MODEL_TYPE_AVATAR_PICTURE_MODEL))
#define DINO_UI_VIEW_MODEL_IS_AVATAR_PICTURE_MODEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_UI_VIEW_MODEL_TYPE_AVATAR_PICTURE_MODEL))
#define DINO_UI_VIEW_MODEL_AVATAR_PICTURE_MODEL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_UI_VIEW_MODEL_TYPE_AVATAR_PICTURE_MODEL, DinoUiViewModelAvatarPictureModelClass))

typedef struct _DinoUiViewModelAvatarPictureModel DinoUiViewModelAvatarPictureModel;
typedef struct _DinoUiViewModelAvatarPictureModelClass DinoUiViewModelAvatarPictureModelClass;

#define DINO_UI_VIEW_MODEL_TYPE_COMPAT_AVATAR_PICTURE_MODEL (dino_ui_view_model_compat_avatar_picture_model_get_type ())
#define DINO_UI_VIEW_MODEL_COMPAT_AVATAR_PICTURE_MODEL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DINO_UI_VIEW_MODEL_TYPE_COMPAT_AVATAR_PICTURE_MODEL, DinoUiViewModelCompatAvatarPictureModel))
#define DINO_UI_VIEW_MODEL_COMPAT_AVATAR_PICTURE_MODEL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DINO_UI_VIEW_MODEL_TYPE_COMPAT_AVATAR_PICTURE_MODEL, DinoUiViewModelCompatAvatarPictureModelClass))
#define DINO_UI_VIEW_MODEL_IS_COMPAT_AVATAR_PICTURE_MODEL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DINO_UI_VIEW_MODEL_TYPE_COMPAT_AVATAR_PICTURE_MODEL))
#define DINO_UI_VIEW_MODEL_IS_COMPAT_AVATAR_PICTURE_MODEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DINO_UI_VIEW_MODEL_TYPE_COMPAT_AVATAR_PICTURE_MODEL))
#define DINO_UI_VIEW_MODEL_COMPAT_AVATAR_PICTURE_MODEL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DINO_UI_VIEW_MODEL_TYPE_COMPAT_AVATAR_PICTURE_MODEL, DinoUiViewModelCompatAvatarPictureModelClass))

typedef struct _DinoUiViewModelCompatAvatarPictureModel DinoUiViewModelCompatAvatarPictureModel;
typedef struct _DinoUiViewModelCompatAvatarPictureModelClass DinoUiViewModelCompatAvatarPictureModelClass;
#define _g_variant_type_free0(var) ((var == NULL) ? NULL : (var = (g_variant_type_free (var), NULL)))
#define _g_bytes_unref0(var) ((var == NULL) ? NULL : (var = (g_bytes_unref (var), NULL)))
#define _cairo_surface_destroy0(var) ((var == NULL) ? NULL : (var = (cairo_surface_destroy (var), NULL)))
#define _dino_ui_compat_avatar_drawer_unref0(var) ((var == NULL) ? NULL : (var = (dino_ui_compat_avatar_drawer_unref (var), NULL)))
typedef struct _DinoUiFreeDesktopNotifierGetConversationIconData DinoUiFreeDesktopNotifierGetConversationIconData;
typedef struct _DinoUiFreeDesktopNotifierParamSpecListenerFuncWrapper DinoUiFreeDesktopNotifierParamSpecListenerFuncWrapper;
enum  {
	DINO_UI_FREE_DESKTOP_NOTIFIER_CONVERSATION_SELECTED_SIGNAL,
	DINO_UI_FREE_DESKTOP_NOTIFIER_NUM_SIGNALS
};
static guint dino_ui_free_desktop_notifier_signals[DINO_UI_FREE_DESKTOP_NOTIFIER_NUM_SIGNALS] = {0};

struct _DinoUiFreeDesktopNotifier {
	GObject parent_instance;
	DinoUiFreeDesktopNotifierPrivate * priv;
};

struct _DinoUiFreeDesktopNotifierClass {
	GObjectClass parent_class;
};

struct _DinoUiFreeDesktopNotifierPrivate {
	DinoStreamInteractor* stream_interactor;
	DinoDBusNotifications* dbus_notifications;
	gboolean supports_body_markup;
	gboolean supports_body_hyperlinks;
	GeeHashMap* content_notifications;
	GeeHashMap* conversation_notifications;
	GeeHashMap* action_listeners;
	GeeHashMap* call_notifications;
};

struct _DinoUiFreeDesktopNotifierListenerFuncWrapper {
	GTypeInstance parent_instance;
	volatile int ref_count;
	DinoUiFreeDesktopNotifierListenerFuncWrapperPrivate * priv;
	DinoUiFreeDesktopNotifierListenerFunc func;
	gpointer func_target;
	GDestroyNotify func_target_destroy_notify;
};

struct _DinoUiFreeDesktopNotifierListenerFuncWrapperClass {
	GTypeClass parent_class;
	void (*finalize) (DinoUiFreeDesktopNotifierListenerFuncWrapper *self);
};

struct _DinoUiFreeDesktopNotifierInitDbusNotificationsData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	DinoUiFreeDesktopNotifier* self;
	gchar** caps;
	gint caps_length1;
	gint _caps_size_;
	DinoDBusNotifications* _tmp0_;
	gchar** _tmp1_;
	gint _tmp2_;
	gchar** _tmp3_;
	gint _tmp3__length1;
	gchar** cap_collection;
	gint cap_collection_length1;
	gint _cap_collection_size_;
	gint cap_it;
	gchar* _tmp4_;
	gchar* cap;
	const gchar* _tmp5_;
	const gchar* _tmp6_;
	GQuark _tmp8_;
	DinoDBusNotifications* _tmp9_;
	DinoDBusNotifications* _tmp10_;
	GError* _inner_error0_;
};

struct _DinoUiFreeDesktopNotifierNotifyMessageData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	DinoUiFreeDesktopNotifier* self;
	DinoEntitiesMessage* message;
	DinoEntitiesConversation* conversation;
	gchar* conversation_display_name;
	gchar* participant_display_name;
	gchar* body;
	gchar* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	gchar* _tmp3_;
	const gchar* _tmp4_;
	const gchar* _tmp5_;
	gchar* _tmp6_;
	const gchar* _tmp7_;
	const gchar* _tmp8_;
	gchar* _tmp9_;
	const gchar* _tmp10_;
};

struct _DinoUiFreeDesktopNotifierNotifyFileData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	DinoUiFreeDesktopNotifier* self;
	DinoEntitiesFileTransfer* file_transfer;
	DinoEntitiesConversation* conversation;
	gboolean is_image;
	gchar* conversation_display_name;
	gchar* participant_display_name;
	gchar* text;
	gchar* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	const gchar* _tmp5_;
	gchar* _tmp6_;
	const gchar* _tmp7_;
	const gchar* _tmp8_;
	const gchar* _tmp9_;
	gchar* _tmp10_;
	const gchar* _tmp11_;
	gchar* _tmp12_;
	gchar* _tmp13_;
	gchar* _tmp14_;
	const gchar* _tmp15_;
};

struct _Block63Data {
	int _ref_count_;
	DinoUiFreeDesktopNotifier* self;
	DinoEntitiesConversation* conversation;
	gpointer _async_data_;
};

struct _DinoUiFreeDesktopNotifierNotifyContentItemData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	DinoUiFreeDesktopNotifier* self;
	DinoEntitiesConversation* conversation;
	gchar* conversation_display_name;
	gchar* participant_display_name;
	gchar* body_;
	Block63Data* _data63_;
	gchar* body;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	const gchar* _tmp5_;
	gchar* _tmp6_;
	const gchar* _tmp7_;
	const gchar* _tmp8_;
	const gchar* _tmp9_;
	gchar* _tmp10_;
	guint32 _tmp11_;
	GeeHashMap* _tmp12_;
	GeeHashMap* _tmp13_;
	gpointer _tmp14_;
	guint32 replace_id;
	GHashTable* hash_table;
	GHashTable* _tmp15_;
	gchar* _tmp16_;
	GVariant* _tmp17_;
	gchar* _tmp18_;
	DinoApplication* _tmp19_;
	const gchar* _tmp20_;
	GVariant* _tmp21_;
	gchar* _tmp22_;
	GVariant* _tmp23_;
	gchar** actions;
	gchar* _tmp24_;
	gchar* _tmp25_;
	gchar** _tmp26_;
	gint actions_length1;
	gint _actions_size_;
	guint32 notification_id;
	DinoDBusNotifications* _tmp27_;
	const gchar* _tmp28_;
	GeeHashMap* _tmp29_;
	GError* e;
	GError* _tmp30_;
	const gchar* _tmp31_;
	GError* _inner_error0_;
};

struct _Block64Data {
	int _ref_count_;
	DinoUiFreeDesktopNotifier* self;
	DinoEntitiesCall* call;
	DinoEntitiesConversation* conversation;
	gpointer _async_data_;
};

struct _DinoUiFreeDesktopNotifierNotifyCallData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	DinoUiFreeDesktopNotifier* self;
	DinoEntitiesCall* call;
	DinoEntitiesConversation* conversation;
	gboolean video;
	gboolean multiparty;
	gchar* conversation_display_name;
	Block64Data* _data64_;
	DinoEntitiesAccount* _tmp0_;
	DinoEntitiesAccount* _tmp1_;
	XmppJid* _tmp2_;
	XmppJid* _tmp3_;
	XmppJid* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	gchar* summary;
	gchar* _tmp7_;
	const gchar* _tmp8_;
	const gchar* _tmp9_;
	const gchar* _tmp10_;
	gchar* body;
	gchar* _tmp11_;
	const gchar* _tmp12_;
	const gchar* _tmp13_;
	const gchar* _tmp14_;
	gchar* _tmp15_;
	GHashTable* hash_table;
	GHashTable* _tmp16_;
	gchar* _tmp17_;
	GVariant* _tmp18_;
	gchar* _tmp19_;
	GVariant* _tmp20_;
	gchar* _tmp21_;
	GVariant* _tmp22_;
	gchar* _tmp23_;
	DinoApplication* _tmp24_;
	const gchar* _tmp25_;
	GVariant* _tmp26_;
	gchar* _tmp27_;
	GVariant* _tmp28_;
	gchar** actions;
	gchar* _tmp29_;
	gchar* _tmp30_;
	gchar* _tmp31_;
	const gchar* _tmp32_;
	gchar* _tmp33_;
	gchar* _tmp34_;
	const gchar* _tmp35_;
	gchar* _tmp36_;
	gchar** _tmp37_;
	gint actions_length1;
	gint _actions_size_;
	guint32 notification_id;
	DinoDBusNotifications* _tmp38_;
	const gchar* _tmp39_;
	const gchar* _tmp40_;
	GeeHashMap* _tmp41_;
	GError* e;
	GError* _tmp42_;
	const gchar* _tmp43_;
	GError* _inner_error0_;
};

struct _DinoUiFreeDesktopNotifierRetractCallNotificationData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	DinoUiFreeDesktopNotifier* self;
	DinoEntitiesCall* call;
	DinoEntitiesConversation* conversation;
	GeeHashMap* _tmp0_;
	guint32 notification_id;
	GeeHashMap* _tmp1_;
	gpointer _tmp2_;
	DinoDBusNotifications* _tmp3_;
	GeeHashMap* _tmp4_;
	GeeHashMap* _tmp5_;
	GError* _inner_error0_;
};

struct _Block65Data {
	int _ref_count_;
	DinoUiFreeDesktopNotifier* self;
	DinoEntitiesConversation* conversation;
	gpointer _async_data_;
};

struct _DinoUiFreeDesktopNotifierNotifySubscriptionRequestData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	DinoUiFreeDesktopNotifier* self;
	DinoEntitiesConversation* conversation;
	Block65Data* _data65_;
	gchar* summary;
	const gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* body;
	XmppJid* _tmp2_;
	XmppJid* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	GHashTable* hash_table;
	GHashTable* _tmp8_;
	gchar* _tmp9_;
	GVariant* _tmp10_;
	gchar* _tmp11_;
	DinoApplication* _tmp12_;
	const gchar* _tmp13_;
	GVariant* _tmp14_;
	gchar* _tmp15_;
	GVariant* _tmp16_;
	gchar** actions;
	gchar* _tmp17_;
	gchar* _tmp18_;
	gchar* _tmp19_;
	const gchar* _tmp20_;
	gchar* _tmp21_;
	gchar* _tmp22_;
	const gchar* _tmp23_;
	gchar* _tmp24_;
	gchar** _tmp25_;
	gint actions_length1;
	gint _actions_size_;
	guint32 notification_id;
	DinoDBusNotifications* _tmp26_;
	GeeHashMap* _tmp27_;
	GeeHashMap* _tmp28_;
	GeeArrayList* _tmp29_;
	GeeArrayList* _tmp30_;
	GeeHashMap* _tmp31_;
	gpointer _tmp32_;
	GeeList* _tmp33_;
	GError* e;
	GError* _tmp34_;
	const gchar* _tmp35_;
	GError* _inner_error0_;
};

struct _Block66Data {
	int _ref_count_;
	DinoUiFreeDesktopNotifier* self;
	DinoEntitiesAccount* account;
	gpointer _async_data_;
};

struct _DinoUiFreeDesktopNotifierNotifyConnectionErrorData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	DinoUiFreeDesktopNotifier* self;
	DinoEntitiesAccount* account;
	DinoConnectionManagerConnectionError* _error_;
	Block66Data* _data66_;
	gchar* summary;
	const gchar* _tmp0_;
	XmppJid* _tmp1_;
	XmppJid* _tmp2_;
	XmppJid* _tmp3_;
	const gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	gchar* body;
	gchar* _tmp7_;
	const gchar* _tmp8_;
	gchar* _tmp9_;
	const gchar* _tmp10_;
	gchar* _tmp11_;
	GHashTable* hash_table;
	GHashTable* _tmp12_;
	gchar* _tmp13_;
	DinoApplication* _tmp14_;
	const gchar* _tmp15_;
	GVariant* _tmp16_;
	gchar* _tmp17_;
	GVariant* _tmp18_;
	gchar** actions;
	gchar* _tmp19_;
	gchar* _tmp20_;
	gchar** _tmp21_;
	gint actions_length1;
	gint _actions_size_;
	guint32 notification_id;
	DinoDBusNotifications* _tmp22_;
	const gchar* _tmp23_;
	const gchar* _tmp24_;
	GError* e;
	GError* _tmp25_;
	const gchar* _tmp26_;
	GError* _inner_error0_;
};

struct _Block67Data {
	int _ref_count_;
	DinoUiFreeDesktopNotifier* self;
	DinoEntitiesConversation* group_conversation;
};

struct _DinoUiFreeDesktopNotifierNotifyMucInviteData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	DinoUiFreeDesktopNotifier* self;
	DinoEntitiesAccount* account;
	XmppJid* room_jid;
	XmppJid* from_jid;
	gchar* inviter_display_name;
	DinoEntitiesConversation* direct_conversation;
	DinoEntitiesConversation* _tmp0_;
	gchar* display_room;
	XmppJid* _tmp1_;
	XmppJid* _tmp2_;
	XmppJid* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* summary;
	const gchar* _tmp6_;
	const gchar* _tmp7_;
	gchar* _tmp8_;
	gchar* body;
	const gchar* _tmp9_;
	const gchar* _tmp10_;
	gchar* _tmp11_;
	const gchar* _tmp12_;
	gchar* _tmp13_;
	GHashTable* hash_table;
	GHashTable* _tmp14_;
	gchar* _tmp15_;
	DinoEntitiesConversation* _tmp16_;
	GVariant* _tmp17_;
	gchar* _tmp18_;
	DinoApplication* _tmp19_;
	const gchar* _tmp20_;
	GVariant* _tmp21_;
	gchar* _tmp22_;
	GVariant* _tmp23_;
	gchar** actions;
	gchar* _tmp24_;
	gchar* _tmp25_;
	gchar* _tmp26_;
	const gchar* _tmp27_;
	gchar* _tmp28_;
	gchar* _tmp29_;
	const gchar* _tmp30_;
	gchar* _tmp31_;
	gchar** _tmp32_;
	gint actions_length1;
	gint _actions_size_;
	Block67Data* _data67_;
	guint32 notification_id;
	DinoDBusNotifications* _tmp33_;
	const gchar* _tmp34_;
	const gchar* _tmp35_;
	DinoStreamInteractor* _tmp36_;
	DinoModuleIdentity* _tmp37_;
	gpointer _tmp38_;
	DinoConversationManager* _tmp39_;
	DinoEntitiesConversationType _tmp40_;
	DinoEntitiesConversation* _tmp41_;
	DinoEntitiesConversation* _tmp42_;
	GError* e;
	GError* _tmp43_;
	const gchar* _tmp44_;
	GError* _inner_error0_;
};

struct _Block68Data {
	int _ref_count_;
	DinoUiFreeDesktopNotifier* self;
	DinoEntitiesConversation* conversation;
	gpointer _async_data_;
};

struct _DinoUiFreeDesktopNotifierNotifyVoiceRequestData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	DinoUiFreeDesktopNotifier* self;
	DinoEntitiesConversation* conversation;
	XmppJid* from_jid;
	Block68Data* _data68_;
	gchar* display_name;
	DinoStreamInteractor* _tmp0_;
	gchar* _tmp1_;
	gchar* display_room;
	DinoStreamInteractor* _tmp2_;
	gchar* _tmp3_;
	gchar* summary;
	const gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* body;
	const gchar* _tmp6_;
	const gchar* _tmp7_;
	const gchar* _tmp8_;
	gchar* _tmp9_;
	const gchar* _tmp10_;
	gchar* _tmp11_;
	gchar* _tmp12_;
	GHashTable* hash_table;
	GHashTable* _tmp13_;
	gchar* _tmp14_;
	GVariant* _tmp15_;
	gchar* _tmp16_;
	DinoApplication* _tmp17_;
	const gchar* _tmp18_;
	GVariant* _tmp19_;
	gchar* _tmp20_;
	GVariant* _tmp21_;
	gchar** actions;
	gchar* _tmp22_;
	const gchar* _tmp23_;
	gchar* _tmp24_;
	gchar* _tmp25_;
	const gchar* _tmp26_;
	gchar* _tmp27_;
	gchar** _tmp28_;
	gint actions_length1;
	gint _actions_size_;
	guint32 notification_id;
	DinoDBusNotifications* _tmp29_;
	const gchar* _tmp30_;
	const gchar* _tmp31_;
	GError* e;
	GError* _tmp32_;
	const gchar* _tmp33_;
	GError* _inner_error0_;
};

struct _DinoUiFreeDesktopNotifierRetractContentItemNotificationsData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	DinoUiFreeDesktopNotifier* self;
	GeeIterator* _id_it;
	GeeHashMap* _tmp0_;
	GeeCollection* _tmp1_;
	GeeCollection* _tmp2_;
	GeeCollection* _tmp3_;
	GeeIterator* _tmp4_;
	GeeIterator* _tmp5_;
	GeeIterator* _tmp6_;
	guint32 id;
	GeeIterator* _tmp7_;
	gpointer _tmp8_;
	DinoDBusNotifications* _tmp9_;
	GeeHashMap* _tmp10_;
	GError* _inner_error0_;
};

struct _DinoUiFreeDesktopNotifierRetractConversationNotificationsData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	DinoUiFreeDesktopNotifier* self;
	DinoEntitiesConversation* conversation;
	GeeHashMap* _tmp0_;
	DinoDBusNotifications* _tmp1_;
	GeeHashMap* _tmp2_;
	gpointer _tmp3_;
	GeeHashMap* _tmp4_;
	GeeHashMap* _tmp5_;
	GeeList* _notification_id_list;
	GeeHashMap* _tmp6_;
	gpointer _tmp7_;
	gint _notification_id_size;
	GeeList* _tmp8_;
	gint _tmp9_;
	gint _tmp10_;
	gint _notification_id_index;
	gint _tmp11_;
	gint _tmp12_;
	guint32 notification_id;
	GeeList* _tmp13_;
	gpointer _tmp14_;
	DinoDBusNotifications* _tmp15_;
	GeeHashMap* _tmp16_;
	GError* _inner_error0_;
};

struct _DinoUiFreeDesktopNotifierGetConversationIconData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	DinoUiFreeDesktopNotifier* self;
	DinoEntitiesConversation* conversation;
	GVariant* result;
	DinoUiCompatAvatarDrawer* drawer;
	DinoStreamInteractor* _tmp0_;
	DinoUiViewModelCompatAvatarPictureModel* _tmp1_;
	DinoUiViewModelCompatAvatarPictureModel* _tmp2_;
	DinoUiViewModelCompatAvatarPictureModel* _tmp3_;
	DinoUiCompatAvatarDrawer* _tmp4_;
	DinoUiCompatAvatarDrawer* _tmp5_;
	cairo_surface_t* surface;
	cairo_surface_t* _tmp6_;
	GdkPixbuf* avatar;
	GdkPixbuf* _tmp7_;
	GBytes* bytes;
	GBytes* _tmp8_;
	GBytes* _tmp9_;
	GVariant* image_bytes;
	GVariantType* _tmp10_;
	GVariantType* _tmp11_;
	gsize _tmp12_;
	guint8* _tmp13_;
	GBytes* _tmp14_;
	GVariant* _tmp15_;
	GVariant* _tmp16_;
	gint _tmp17_;
	gint _tmp18_;
	gint _tmp19_;
	gint _tmp20_;
	gint _tmp21_;
	gint _tmp22_;
	gboolean _tmp23_;
	gboolean _tmp24_;
	gint _tmp25_;
	gint _tmp26_;
	gint _tmp27_;
	gint _tmp28_;
	GVariant* _tmp29_;
};

struct _DinoUiFreeDesktopNotifierParamSpecListenerFuncWrapper {
	GParamSpec parent_instance;
};

static gint DinoUiFreeDesktopNotifier_private_offset;
static gpointer dino_ui_free_desktop_notifier_parent_class = NULL;
static gpointer dino_ui_free_desktop_notifier_listener_func_wrapper_parent_class = NULL;
static DinoNotificationProviderIface * dino_ui_free_desktop_notifier_dino_notification_provider_parent_iface = NULL;

VALA_EXTERN GType dino_ui_free_desktop_notifier_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoUiFreeDesktopNotifier, g_object_unref)
static gpointer dino_ui_free_desktop_notifier_listener_func_wrapper_ref (gpointer instance);
static void dino_ui_free_desktop_notifier_listener_func_wrapper_unref (gpointer instance);
static GParamSpec* dino_ui_free_desktop_notifier_param_spec_listener_func_wrapper (const gchar* name,
                                                                            const gchar* nick,
                                                                            const gchar* blurb,
                                                                            GType object_type,
                                                                            GParamFlags flags) G_GNUC_UNUSED ;
static void dino_ui_free_desktop_notifier_value_set_listener_func_wrapper (GValue* value,
                                                                    gpointer v_object) G_GNUC_UNUSED ;
static void dino_ui_free_desktop_notifier_value_take_listener_func_wrapper (GValue* value,
                                                                     gpointer v_object) G_GNUC_UNUSED ;
static gpointer dino_ui_free_desktop_notifier_value_get_listener_func_wrapper (const GValue* value) G_GNUC_UNUSED ;
static GType dino_ui_free_desktop_notifier_listener_func_wrapper_get_type (void) G_GNUC_CONST  G_GNUC_UNUSED ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoUiFreeDesktopNotifierListenerFuncWrapper, dino_ui_free_desktop_notifier_listener_func_wrapper_unref)
static guint _dino_entities_conversation_hash_func_gee_hash_data_func (gconstpointer v,
                                                                gpointer self);
static gboolean _dino_entities_conversation_equals_func_gee_equal_data_func (gconstpointer a,
                                                                      gconstpointer b,
                                                                      gpointer self);
static guint _dino_entities_call_hash_func_gee_hash_data_func (gconstpointer v,
                                                        gpointer self);
static gboolean _dino_entities_call_equals_func_gee_equal_data_func (gconstpointer a,
                                                              gconstpointer b,
                                                              gpointer self);
VALA_EXTERN DinoUiFreeDesktopNotifier* dino_ui_free_desktop_notifier_new (DinoStreamInteractor* stream_interactor,
                                                              DinoDBusNotifications* dbus_notifications);
VALA_EXTERN DinoUiFreeDesktopNotifier* dino_ui_free_desktop_notifier_construct (GType object_type,
                                                                    DinoStreamInteractor* stream_interactor,
                                                                    DinoDBusNotifications* dbus_notifications);
static void dino_ui_free_desktop_notifier_init_dbus_notifications (DinoUiFreeDesktopNotifier* self,
                                                            GAsyncReadyCallback _callback_,
                                                            gpointer _user_data_);
static void dino_ui_free_desktop_notifier_init_dbus_notifications_finish (DinoUiFreeDesktopNotifier* self,
                                                                   GAsyncResult* _res_,
                                                                   GError** error);
static void dino_ui_free_desktop_notifier_init_dbus_notifications_data_free (gpointer _data);
static gboolean dino_ui_free_desktop_notifier_init_dbus_notifications_co (DinoUiFreeDesktopNotifierInitDbusNotificationsData* _data_);
static void dino_ui_free_desktop_notifier_init_dbus_notifications_ready (GObject* source_object,
                                                                  GAsyncResult* _res_,
                                                                  gpointer _user_data_);
static void __lambda318_ (DinoUiFreeDesktopNotifier* self,
                   guint32 id,
                   const gchar* action);
static void ___lambda318__dino_dbus_notifications_action_invoked (DinoDBusNotifications* _sender,
                                                           guint32 key,
                                                           const gchar* action_key,
                                                           gpointer self);
static void __lambda319_ (DinoUiFreeDesktopNotifier* self,
                   guint32 id);
static void ___lambda319__dino_dbus_notifications_notification_closed (DinoDBusNotifications* _sender,
                                                                guint32 id,
                                                                guint32 reason,
                                                                gpointer self);
static gdouble dino_ui_free_desktop_notifier_real_get_priority (DinoNotificationProvider* base);
static void dino_ui_free_desktop_notifier_real_notify_message_data_free (gpointer _data);
static void dino_ui_free_desktop_notifier_real_notify_message (DinoNotificationProvider* base,
                                                        DinoEntitiesMessage* message,
                                                        DinoEntitiesConversation* conversation,
                                                        const gchar* conversation_display_name,
                                                        const gchar* participant_display_name,
                                                        GAsyncReadyCallback _callback_,
                                                        gpointer _user_data_);
static gboolean dino_ui_free_desktop_notifier_real_notify_message_co (DinoUiFreeDesktopNotifierNotifyMessageData* _data_);
VALA_EXTERN gchar* dino_ui_util_parse_add_markup (const gchar* s_,
                                      const gchar* highlight_word,
                                      gboolean parse_links,
                                      gboolean parse_text_markup);
static void dino_ui_free_desktop_notifier_notify_content_item (DinoUiFreeDesktopNotifier* self,
                                                        DinoEntitiesConversation* conversation,
                                                        const gchar* conversation_display_name,
                                                        const gchar* participant_display_name,
                                                        const gchar* body_,
                                                        GAsyncReadyCallback _callback_,
                                                        gpointer _user_data_);
static void dino_ui_free_desktop_notifier_notify_content_item_finish (DinoUiFreeDesktopNotifier* self,
                                                               GAsyncResult* _res_);
static void dino_ui_free_desktop_notifier_notify_message_ready (GObject* source_object,
                                                         GAsyncResult* _res_,
                                                         gpointer _user_data_);
static void dino_ui_free_desktop_notifier_real_notify_file_data_free (gpointer _data);
static void dino_ui_free_desktop_notifier_real_notify_file (DinoNotificationProvider* base,
                                                     DinoEntitiesFileTransfer* file_transfer,
                                                     DinoEntitiesConversation* conversation,
                                                     gboolean is_image,
                                                     const gchar* conversation_display_name,
                                                     const gchar* participant_display_name,
                                                     GAsyncReadyCallback _callback_,
                                                     gpointer _user_data_);
static gboolean dino_ui_free_desktop_notifier_real_notify_file_co (DinoUiFreeDesktopNotifierNotifyFileData* _data_);
static void dino_ui_free_desktop_notifier_notify_file_ready (GObject* source_object,
                                                      GAsyncResult* _res_,
                                                      gpointer _user_data_);
static void dino_ui_free_desktop_notifier_notify_content_item_data_free (gpointer _data);
static gboolean dino_ui_free_desktop_notifier_notify_content_item_co (DinoUiFreeDesktopNotifierNotifyContentItemData* _data_);
static Block63Data* block63_data_ref (Block63Data* _data63_);
static void block63_data_unref (void * _userdata_);
static void _g_free0_ (gpointer var);
static void _g_variant_unref0_ (gpointer var);
static void dino_ui_free_desktop_notifier_get_conversation_icon (DinoUiFreeDesktopNotifier* self,
                                                          DinoEntitiesConversation* conversation,
                                                          GAsyncReadyCallback _callback_,
                                                          gpointer _user_data_);
static GVariant* dino_ui_free_desktop_notifier_get_conversation_icon_finish (DinoUiFreeDesktopNotifier* self,
                                                                      GAsyncResult* _res_);
static void dino_ui_free_desktop_notifier_notify_content_item_ready (GObject* source_object,
                                                              GAsyncResult* _res_,
                                                              gpointer _user_data_);
static void dino_ui_free_desktop_notifier_add_action_listener (DinoUiFreeDesktopNotifier* self,
                                                        guint32 id,
                                                        const gchar* name,
                                                        DinoUiFreeDesktopNotifierListenerFunc func,
                                                        gpointer func_target,
                                                        GDestroyNotify func_target_destroy_notify);
static void ___lambda320_ (Block63Data* _data63_);
static void ____lambda320__dino_ui_free_desktop_notifier_listener_func (gpointer self);
static void dino_ui_free_desktop_notifier_real_notify_call_data_free (gpointer _data);
static void dino_ui_free_desktop_notifier_real_notify_call (DinoNotificationProvider* base,
                                                     DinoEntitiesCall* call,
                                                     DinoEntitiesConversation* conversation,
                                                     gboolean video,
                                                     gboolean multiparty,
                                                     const gchar* conversation_display_name,
                                                     GAsyncReadyCallback _callback_,
                                                     gpointer _user_data_);
static gboolean dino_ui_free_desktop_notifier_real_notify_call_co (DinoUiFreeDesktopNotifierNotifyCallData* _data_);
static Block64Data* block64_data_ref (Block64Data* _data64_);
static void block64_data_unref (void * _userdata_);
static GVariant* _variant_new4 (const gchar* value);
static void dino_ui_free_desktop_notifier_notify_call_ready (GObject* source_object,
                                                      GAsyncResult* _res_,
                                                      gpointer _user_data_);
static void ___lambda321_ (Block64Data* _data64_);
static void ____lambda321__dino_ui_free_desktop_notifier_listener_func (gpointer self);
static void ___lambda322_ (Block64Data* _data64_);
static void ____lambda322__dino_ui_free_desktop_notifier_listener_func (gpointer self);
static void ___lambda323_ (Block64Data* _data64_);
static void ____lambda323__dino_ui_free_desktop_notifier_listener_func (gpointer self);
static void dino_ui_free_desktop_notifier_real_retract_call_notification_data_free (gpointer _data);
static void dino_ui_free_desktop_notifier_real_retract_call_notification (DinoNotificationProvider* base,
                                                                   DinoEntitiesCall* call,
                                                                   DinoEntitiesConversation* conversation,
                                                                   GAsyncReadyCallback _callback_,
                                                                   gpointer _user_data_);
static gboolean dino_ui_free_desktop_notifier_real_retract_call_notification_co (DinoUiFreeDesktopNotifierRetractCallNotificationData* _data_);
static void dino_ui_free_desktop_notifier_retract_call_notification_ready (GObject* source_object,
                                                                    GAsyncResult* _res_,
                                                                    gpointer _user_data_);
static void dino_ui_free_desktop_notifier_real_notify_subscription_request_data_free (gpointer _data);
static void dino_ui_free_desktop_notifier_real_notify_subscription_request (DinoNotificationProvider* base,
                                                                     DinoEntitiesConversation* conversation,
                                                                     GAsyncReadyCallback _callback_,
                                                                     gpointer _user_data_);
static gboolean dino_ui_free_desktop_notifier_real_notify_subscription_request_co (DinoUiFreeDesktopNotifierNotifySubscriptionRequestData* _data_);
static Block65Data* block65_data_ref (Block65Data* _data65_);
static void block65_data_unref (void * _userdata_);
static void dino_ui_free_desktop_notifier_notify_subscription_request_ready (GObject* source_object,
                                                                      GAsyncResult* _res_,
                                                                      gpointer _user_data_);
static void ___lambda324_ (Block65Data* _data65_);
static void ____lambda324__dino_ui_free_desktop_notifier_listener_func (gpointer self);
static void ___lambda325_ (Block65Data* _data65_);
static void ____lambda325__dino_ui_free_desktop_notifier_listener_func (gpointer self);
static void ___lambda326_ (Block65Data* _data65_);
static void ____lambda326__dino_ui_free_desktop_notifier_listener_func (gpointer self);
static void dino_ui_free_desktop_notifier_real_notify_connection_error_data_free (gpointer _data);
static void dino_ui_free_desktop_notifier_real_notify_connection_error (DinoNotificationProvider* base,
                                                                 DinoEntitiesAccount* account,
                                                                 DinoConnectionManagerConnectionError* _error_,
                                                                 GAsyncReadyCallback _callback_,
                                                                 gpointer _user_data_);
static gboolean dino_ui_free_desktop_notifier_real_notify_connection_error_co (DinoUiFreeDesktopNotifierNotifyConnectionErrorData* _data_);
static Block66Data* block66_data_ref (Block66Data* _data66_);
static void block66_data_unref (void * _userdata_);
static void dino_ui_free_desktop_notifier_notify_connection_error_ready (GObject* source_object,
                                                                  GAsyncResult* _res_,
                                                                  gpointer _user_data_);
static void ___lambda327_ (Block66Data* _data66_);
static void ____lambda327__dino_ui_free_desktop_notifier_listener_func (gpointer self);
static void dino_ui_free_desktop_notifier_real_notify_muc_invite_data_free (gpointer _data);
static void dino_ui_free_desktop_notifier_real_notify_muc_invite (DinoNotificationProvider* base,
                                                           DinoEntitiesAccount* account,
                                                           XmppJid* room_jid,
                                                           XmppJid* from_jid,
                                                           const gchar* inviter_display_name,
                                                           GAsyncReadyCallback _callback_,
                                                           gpointer _user_data_);
static gboolean dino_ui_free_desktop_notifier_real_notify_muc_invite_co (DinoUiFreeDesktopNotifierNotifyMucInviteData* _data_);
static void dino_ui_free_desktop_notifier_notify_muc_invite_ready (GObject* source_object,
                                                            GAsyncResult* _res_,
                                                            gpointer _user_data_);
static Block67Data* block67_data_ref (Block67Data* _data67_);
static void block67_data_unref (void * _userdata_);
static void ___lambda328_ (Block67Data* _data67_);
static void ____lambda328__dino_ui_free_desktop_notifier_listener_func (gpointer self);
static void ___lambda329_ (Block67Data* _data67_);
static void ____lambda329__dino_ui_free_desktop_notifier_listener_func (gpointer self);
static void ___lambda330_ (Block67Data* _data67_);
static void ____lambda330__dino_ui_free_desktop_notifier_listener_func (gpointer self);
static void dino_ui_free_desktop_notifier_real_notify_voice_request_data_free (gpointer _data);
static void dino_ui_free_desktop_notifier_real_notify_voice_request (DinoNotificationProvider* base,
                                                              DinoEntitiesConversation* conversation,
                                                              XmppJid* from_jid,
                                                              GAsyncReadyCallback _callback_,
                                                              gpointer _user_data_);
static gboolean dino_ui_free_desktop_notifier_real_notify_voice_request_co (DinoUiFreeDesktopNotifierNotifyVoiceRequestData* _data_);
static Block68Data* block68_data_ref (Block68Data* _data68_);
static void block68_data_unref (void * _userdata_);
VALA_EXTERN gchar* dino_ui_util_get_participant_display_name (DinoStreamInteractor* stream_interactor,
                                                  DinoEntitiesConversation* conversation,
                                                  XmppJid* participant,
                                                  gboolean me_is_me);
VALA_EXTERN gchar* dino_ui_util_get_conversation_display_name (DinoStreamInteractor* stream_interactor,
                                                   DinoEntitiesConversation* conversation);
static void dino_ui_free_desktop_notifier_notify_voice_request_ready (GObject* source_object,
                                                               GAsyncResult* _res_,
                                                               gpointer _user_data_);
static void ___lambda331_ (Block68Data* _data68_);
static void ____lambda331__dino_ui_free_desktop_notifier_listener_func (gpointer self);
static void ___lambda332_ (Block68Data* _data68_);
static void ____lambda332__dino_ui_free_desktop_notifier_listener_func (gpointer self);
static void dino_ui_free_desktop_notifier_real_retract_content_item_notifications_data_free (gpointer _data);
static void dino_ui_free_desktop_notifier_real_retract_content_item_notifications (DinoNotificationProvider* base,
                                                                            GAsyncReadyCallback _callback_,
                                                                            gpointer _user_data_);
static gboolean dino_ui_free_desktop_notifier_real_retract_content_item_notifications_co (DinoUiFreeDesktopNotifierRetractContentItemNotificationsData* _data_);
static void dino_ui_free_desktop_notifier_real_retract_conversation_notifications_data_free (gpointer _data);
static void dino_ui_free_desktop_notifier_real_retract_conversation_notifications (DinoNotificationProvider* base,
                                                                            DinoEntitiesConversation* conversation,
                                                                            GAsyncReadyCallback _callback_,
                                                                            gpointer _user_data_);
static gboolean dino_ui_free_desktop_notifier_real_retract_conversation_notifications_co (DinoUiFreeDesktopNotifierRetractConversationNotificationsData* _data_);
static void dino_ui_free_desktop_notifier_get_conversation_icon_data_free (gpointer _data);
static gboolean dino_ui_free_desktop_notifier_get_conversation_icon_co (DinoUiFreeDesktopNotifierGetConversationIconData* _data_);
VALA_EXTERN gpointer dino_ui_compat_avatar_drawer_ref (gpointer instance);
VALA_EXTERN void dino_ui_compat_avatar_drawer_unref (gpointer instance);
VALA_EXTERN GParamSpec* dino_ui_param_spec_compat_avatar_drawer (const gchar* name,
                                                     const gchar* nick,
                                                     const gchar* blurb,
                                                     GType object_type,
                                                     GParamFlags flags);
VALA_EXTERN void dino_ui_value_set_compat_avatar_drawer (GValue* value,
                                             gpointer v_object);
VALA_EXTERN void dino_ui_value_take_compat_avatar_drawer (GValue* value,
                                              gpointer v_object);
VALA_EXTERN gpointer dino_ui_value_get_compat_avatar_drawer (const GValue* value);
VALA_EXTERN GType dino_ui_compat_avatar_drawer_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoUiCompatAvatarDrawer, dino_ui_compat_avatar_drawer_unref)
VALA_EXTERN DinoUiViewModelCompatAvatarPictureModel* dino_ui_view_model_compat_avatar_picture_model_new (DinoStreamInteractor* stream_interactor);
VALA_EXTERN DinoUiViewModelCompatAvatarPictureModel* dino_ui_view_model_compat_avatar_picture_model_construct (GType object_type,
                                                                                                   DinoStreamInteractor* stream_interactor);
VALA_EXTERN GType dino_ui_view_model_avatar_picture_model_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoUiViewModelAvatarPictureModel, g_object_unref)
VALA_EXTERN GType dino_ui_view_model_compat_avatar_picture_model_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DinoUiViewModelCompatAvatarPictureModel, g_object_unref)
VALA_EXTERN DinoUiViewModelCompatAvatarPictureModel* dino_ui_view_model_compat_avatar_picture_model_set_conversation (DinoUiViewModelCompatAvatarPictureModel* self,
                                                                                                          DinoEntitiesConversation* conversation);
VALA_EXTERN DinoUiCompatAvatarDrawer* dino_ui_compat_avatar_drawer_new (void);
VALA_EXTERN DinoUiCompatAvatarDrawer* dino_ui_compat_avatar_drawer_construct (GType object_type);
VALA_EXTERN void dino_ui_compat_avatar_drawer_set_model (DinoUiCompatAvatarDrawer* self,
                                             DinoUiViewModelAvatarPictureModel* value);
VALA_EXTERN void dino_ui_compat_avatar_drawer_set_width_request (DinoUiCompatAvatarDrawer* self,
                                                     gint value);
VALA_EXTERN void dino_ui_compat_avatar_drawer_set_height_request (DinoUiCompatAvatarDrawer* self,
                                                      gint value);
VALA_EXTERN cairo_surface_t* dino_ui_compat_avatar_drawer_draw_image_surface (DinoUiCompatAvatarDrawer* self);
static DinoUiFreeDesktopNotifierListenerFuncWrapper* dino_ui_free_desktop_notifier_listener_func_wrapper_new (DinoUiFreeDesktopNotifierListenerFunc func,
                                                                                                       gpointer func_target,
                                                                                                       GDestroyNotify func_target_destroy_notify);
static DinoUiFreeDesktopNotifierListenerFuncWrapper* dino_ui_free_desktop_notifier_listener_func_wrapper_construct (GType object_type,
                                                                                                             DinoUiFreeDesktopNotifierListenerFunc func,
                                                                                                             gpointer func_target,
                                                                                                             GDestroyNotify func_target_destroy_notify);
static void dino_ui_free_desktop_notifier_listener_func_wrapper_finalize (DinoUiFreeDesktopNotifierListenerFuncWrapper * obj);
static GType dino_ui_free_desktop_notifier_listener_func_wrapper_get_type_once (void);
static void dino_ui_free_desktop_notifier_finalize (GObject * obj);
static GType dino_ui_free_desktop_notifier_get_type_once (void);
static void _vala_array_destroy (gpointer array,
                          gssize array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gssize array_length,
                       GDestroyNotify destroy_func);
static inline gpointer _vala_memdup2 (gconstpointer mem,
                        gsize byte_size);

static inline gpointer
dino_ui_free_desktop_notifier_get_instance_private (DinoUiFreeDesktopNotifier* self)
{
	return G_STRUCT_MEMBER_P (self, DinoUiFreeDesktopNotifier_private_offset);
}

static guint
_dino_entities_conversation_hash_func_gee_hash_data_func (gconstpointer v,
                                                          gpointer self)
{
	guint result;
	result = dino_entities_conversation_hash_func ((DinoEntitiesConversation*) v);
	return result;
}

static gboolean
_dino_entities_conversation_equals_func_gee_equal_data_func (gconstpointer a,
                                                             gconstpointer b,
                                                             gpointer self)
{
	gboolean result;
	result = dino_entities_conversation_equals_func ((DinoEntitiesConversation*) a, (DinoEntitiesConversation*) b);
	return result;
}

static guint
_dino_entities_call_hash_func_gee_hash_data_func (gconstpointer v,
                                                  gpointer self)
{
	guint result;
	result = dino_entities_call_hash_func ((DinoEntitiesCall*) v);
	return result;
}

static gboolean
_dino_entities_call_equals_func_gee_equal_data_func (gconstpointer a,
                                                     gconstpointer b,
                                                     gpointer self)
{
	gboolean result;
	result = dino_entities_call_equals_func ((DinoEntitiesCall*) a, (DinoEntitiesCall*) b);
	return result;
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

DinoUiFreeDesktopNotifier*
dino_ui_free_desktop_notifier_construct (GType object_type,
                                         DinoStreamInteractor* stream_interactor,
                                         DinoDBusNotifications* dbus_notifications)
{
	DinoUiFreeDesktopNotifier * self = NULL;
	DinoStreamInteractor* _tmp0_;
	DinoDBusNotifications* _tmp1_;
	g_return_val_if_fail (stream_interactor != NULL, NULL);
	g_return_val_if_fail (dbus_notifications != NULL, NULL);
	self = (DinoUiFreeDesktopNotifier*) g_object_new (object_type, NULL);
	_tmp0_ = _g_object_ref0 (stream_interactor);
	_g_object_unref0 (self->priv->stream_interactor);
	self->priv->stream_interactor = _tmp0_;
	_tmp1_ = _g_object_ref0 (dbus_notifications);
	_g_object_unref0 (self->priv->dbus_notifications);
	self->priv->dbus_notifications = _tmp1_;
	dino_ui_free_desktop_notifier_init_dbus_notifications (self, NULL, NULL);
	return self;
}

DinoUiFreeDesktopNotifier*
dino_ui_free_desktop_notifier_new (DinoStreamInteractor* stream_interactor,
                                   DinoDBusNotifications* dbus_notifications)
{
	return dino_ui_free_desktop_notifier_construct (DINO_UI_TYPE_FREE_DESKTOP_NOTIFIER, stream_interactor, dbus_notifications);
}

static void
dino_ui_free_desktop_notifier_init_dbus_notifications_data_free (gpointer _data)
{
	DinoUiFreeDesktopNotifierInitDbusNotificationsData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->self);
	g_slice_free (DinoUiFreeDesktopNotifierInitDbusNotificationsData, _data_);
}

static void
dino_ui_free_desktop_notifier_init_dbus_notifications (DinoUiFreeDesktopNotifier* self,
                                                       GAsyncReadyCallback _callback_,
                                                       gpointer _user_data_)
{
	DinoUiFreeDesktopNotifierInitDbusNotificationsData* _data_;
	DinoUiFreeDesktopNotifier* _tmp0_;
	g_return_if_fail (self != NULL);
	_data_ = g_slice_new0 (DinoUiFreeDesktopNotifierInitDbusNotificationsData);
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
	g_task_set_task_data (_data_->_async_result, _data_, dino_ui_free_desktop_notifier_init_dbus_notifications_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	dino_ui_free_desktop_notifier_init_dbus_notifications_co (_data_);
}

static void
dino_ui_free_desktop_notifier_init_dbus_notifications_finish (DinoUiFreeDesktopNotifier* self,
                                                              GAsyncResult* _res_,
                                                              GError** error)
{
	DinoUiFreeDesktopNotifierInitDbusNotificationsData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), error);
	if (NULL == _data_) {
		return;
	}
}

static void
dino_ui_free_desktop_notifier_init_dbus_notifications_ready (GObject* source_object,
                                                             GAsyncResult* _res_,
                                                             gpointer _user_data_)
{
	DinoUiFreeDesktopNotifierInitDbusNotificationsData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	dino_ui_free_desktop_notifier_init_dbus_notifications_co (_data_);
}

static void
__lambda318_ (DinoUiFreeDesktopNotifier* self,
              guint32 id,
              const gchar* action)
{
	gboolean _tmp0_ = FALSE;
	GeeHashMap* _tmp1_;
	g_return_if_fail (action != NULL);
	_tmp1_ = self->priv->action_listeners;
	if (gee_abstract_map_has_key ((GeeAbstractMap*) _tmp1_, (gpointer) ((guintptr) id))) {
		GeeHashMap* _tmp2_;
		gpointer _tmp3_;
		GeeHashMap* _tmp4_;
		_tmp2_ = self->priv->action_listeners;
		_tmp3_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp2_, (gpointer) ((guintptr) id));
		_tmp4_ = (GeeHashMap*) _tmp3_;
		_tmp0_ = gee_abstract_map_has_key ((GeeAbstractMap*) _tmp4_, action);
		_g_object_unref0 (_tmp4_);
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		GeeHashMap* _tmp5_;
		gpointer _tmp6_;
		GeeHashMap* _tmp7_;
		gpointer _tmp8_;
		DinoUiFreeDesktopNotifierListenerFuncWrapper* _tmp9_;
		DinoUiFreeDesktopNotifierListenerFunc _tmp10_;
		gpointer _tmp10__target;
		_tmp5_ = self->priv->action_listeners;
		_tmp6_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp5_, (gpointer) ((guintptr) id));
		_tmp7_ = (GeeHashMap*) _tmp6_;
		_tmp8_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp7_, action);
		_tmp9_ = (DinoUiFreeDesktopNotifierListenerFuncWrapper*) _tmp8_;
		_tmp10_ = _tmp9_->func;
		_tmp10__target = _tmp9_->func_target;
		_tmp10_ (_tmp10__target);
		_dino_ui_free_desktop_notifier_listener_func_wrapper_unref0 (_tmp9_);
		_g_object_unref0 (_tmp7_);
	}
}

static void
___lambda318__dino_dbus_notifications_action_invoked (DinoDBusNotifications* _sender,
                                                      guint32 key,
                                                      const gchar* action_key,
                                                      gpointer self)
{
	__lambda318_ ((DinoUiFreeDesktopNotifier*) self, key, action_key);
}

static void
__lambda319_ (DinoUiFreeDesktopNotifier* self,
              guint32 id)
{
	GeeHashMap* _tmp0_;
	_tmp0_ = self->priv->action_listeners;
	gee_abstract_map_unset ((GeeAbstractMap*) _tmp0_, (gpointer) ((guintptr) id), NULL);
}

static void
___lambda319__dino_dbus_notifications_notification_closed (DinoDBusNotifications* _sender,
                                                           guint32 id,
                                                           guint32 reason,
                                                           gpointer self)
{
	__lambda319_ ((DinoUiFreeDesktopNotifier*) self, id);
}

static gboolean
dino_ui_free_desktop_notifier_init_dbus_notifications_co (DinoUiFreeDesktopNotifierInitDbusNotificationsData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->caps_length1 = 0;
	_data_->_caps_size_ = 0;
	_data_->_tmp0_ = _data_->self->priv->dbus_notifications;
	_data_->_tmp1_ = NULL;
	_data_->_tmp2_ = 0;
	_data_->_state_ = 1;
	dino_dbus_notifications_get_capabilities (_data_->_tmp0_, dino_ui_free_desktop_notifier_init_dbus_notifications_ready, _data_);
	return FALSE;
	_state_1:
	dino_dbus_notifications_get_capabilities_finish (_data_->_tmp0_, _data_->_res_, &_data_->_tmp1_, &_data_->_tmp2_, &_data_->_inner_error0_);
	_data_->caps = (_vala_array_free (_data_->caps, _data_->caps_length1, (GDestroyNotify) g_free), NULL);
	_data_->caps = _data_->_tmp1_;
	_data_->caps_length1 = _data_->_tmp2_;
	_data_->_caps_size_ = _data_->caps_length1;
	if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
		g_task_return_error (_data_->_async_result, _data_->_inner_error0_);
		_data_->caps = (_vala_array_free (_data_->caps, _data_->caps_length1, (GDestroyNotify) g_free), NULL);
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	_data_->_tmp3_ = _data_->caps;
	_data_->_tmp3__length1 = _data_->caps_length1;
	{
		_data_->cap_collection_length1 = 0;
		_data_->_cap_collection_size_ = 0;
		_data_->cap_collection = _data_->_tmp3_;
		_data_->cap_collection_length1 = _data_->_tmp3__length1;
		for (_data_->cap_it = 0; _data_->cap_it < _data_->cap_collection_length1; _data_->cap_it = _data_->cap_it + 1) {
			_data_->_tmp4_ = g_strdup (_data_->cap_collection[_data_->cap_it]);
			_data_->cap = _data_->_tmp4_;
			{
				static GQuark _tmp7_label0 = 0;
				static GQuark _tmp7_label1 = 0;
				_data_->_tmp5_ = _data_->cap;
				_data_->_tmp8_ = 0U;
				_data_->_tmp6_ = _data_->_tmp5_;
				_data_->_tmp8_ = (NULL == _data_->_tmp6_) ? 0 : g_quark_from_string (_data_->_tmp6_);
				if (_data_->_tmp8_ == ((0 != _tmp7_label0) ? _tmp7_label0 : (_tmp7_label0 = g_quark_from_static_string ("body-markup")))) {
					switch (0) {
						default:
						{
							_data_->self->priv->supports_body_markup = TRUE;
							break;
						}
					}
				} else if (_data_->_tmp8_ == ((0 != _tmp7_label1) ? _tmp7_label1 : (_tmp7_label1 = g_quark_from_static_string ("body-hyperlinks")))) {
					switch (0) {
						default:
						{
							_data_->self->priv->supports_body_hyperlinks = TRUE;
							break;
						}
					}
				}
				_g_free0 (_data_->cap);
			}
		}
	}
	_data_->_tmp9_ = _data_->self->priv->dbus_notifications;
	g_signal_connect_object (_data_->_tmp9_, "action-invoked", (GCallback) ___lambda318__dino_dbus_notifications_action_invoked, _data_->self, 0);
	_data_->_tmp10_ = _data_->self->priv->dbus_notifications;
	g_signal_connect_object (_data_->_tmp10_, "notification-closed", (GCallback) ___lambda319__dino_dbus_notifications_notification_closed, _data_->self, 0);
	_data_->caps = (_vala_array_free (_data_->caps, _data_->caps_length1, (GDestroyNotify) g_free), NULL);
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!g_task_get_completed (_data_->_async_result)) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

static gdouble
dino_ui_free_desktop_notifier_real_get_priority (DinoNotificationProvider* base)
{
	DinoUiFreeDesktopNotifier * self;
	gdouble result;
	self = (DinoUiFreeDesktopNotifier*) base;
	result = (gdouble) 1;
	return result;
}

static void
dino_ui_free_desktop_notifier_real_notify_message_data_free (gpointer _data)
{
	DinoUiFreeDesktopNotifierNotifyMessageData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->message);
	_g_object_unref0 (_data_->conversation);
	_g_free0 (_data_->conversation_display_name);
	_g_free0 (_data_->participant_display_name);
	_g_object_unref0 (_data_->self);
	g_slice_free (DinoUiFreeDesktopNotifierNotifyMessageData, _data_);
}

static void
dino_ui_free_desktop_notifier_real_notify_message (DinoNotificationProvider* base,
                                                   DinoEntitiesMessage* message,
                                                   DinoEntitiesConversation* conversation,
                                                   const gchar* conversation_display_name,
                                                   const gchar* participant_display_name,
                                                   GAsyncReadyCallback _callback_,
                                                   gpointer _user_data_)
{
	DinoUiFreeDesktopNotifier * self;
	DinoUiFreeDesktopNotifierNotifyMessageData* _data_;
	DinoUiFreeDesktopNotifier* _tmp0_;
	DinoEntitiesMessage* _tmp1_;
	DinoEntitiesConversation* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	g_return_if_fail (message != NULL);
	g_return_if_fail (conversation != NULL);
	g_return_if_fail (conversation_display_name != NULL);
	self = (DinoUiFreeDesktopNotifier*) base;
	_data_ = g_slice_new0 (DinoUiFreeDesktopNotifierNotifyMessageData);
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
	g_task_set_task_data (_data_->_async_result, _data_, dino_ui_free_desktop_notifier_real_notify_message_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = _g_object_ref0 (message);
	_g_object_unref0 (_data_->message);
	_data_->message = _tmp1_;
	_tmp2_ = _g_object_ref0 (conversation);
	_g_object_unref0 (_data_->conversation);
	_data_->conversation = _tmp2_;
	_tmp3_ = g_strdup (conversation_display_name);
	_g_free0 (_data_->conversation_display_name);
	_data_->conversation_display_name = _tmp3_;
	_tmp4_ = g_strdup (participant_display_name);
	_g_free0 (_data_->participant_display_name);
	_data_->participant_display_name = _tmp4_;
	dino_ui_free_desktop_notifier_real_notify_message_co (_data_);
}

static void
dino_ui_free_desktop_notifier_notify_message_finish (DinoNotificationProvider* base,
                                                     GAsyncResult* _res_)
{
	DinoUiFreeDesktopNotifierNotifyMessageData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
}

static void
dino_ui_free_desktop_notifier_notify_message_ready (GObject* source_object,
                                                    GAsyncResult* _res_,
                                                    gpointer _user_data_)
{
	DinoUiFreeDesktopNotifierNotifyMessageData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	dino_ui_free_desktop_notifier_real_notify_message_co (_data_);
}

static gboolean
dino_ui_free_desktop_notifier_real_notify_message_co (DinoUiFreeDesktopNotifierNotifyMessageData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_tmp0_ = g_strdup ("");
	_data_->body = _data_->_tmp0_;
	if (_data_->self->priv->supports_body_hyperlinks) {
		_data_->_tmp1_ = dino_entities_message_get_body (_data_->message);
		_data_->_tmp2_ = _data_->_tmp1_;
		_data_->_tmp3_ = dino_ui_util_parse_add_markup (_data_->_tmp2_, NULL, TRUE, FALSE);
		_g_free0 (_data_->body);
		_data_->body = _data_->_tmp3_;
	} else {
		if (_data_->self->priv->supports_body_markup) {
			_data_->_tmp4_ = dino_entities_message_get_body (_data_->message);
			_data_->_tmp5_ = _data_->_tmp4_;
			_data_->_tmp6_ = g_markup_escape_text (_data_->_tmp5_, (gssize) -1);
			_g_free0 (_data_->body);
			_data_->body = _data_->_tmp6_;
		} else {
			_data_->_tmp7_ = dino_entities_message_get_body (_data_->message);
			_data_->_tmp8_ = _data_->_tmp7_;
			_data_->_tmp9_ = g_strdup (_data_->_tmp8_);
			_g_free0 (_data_->body);
			_data_->body = _data_->_tmp9_;
		}
	}
	_data_->_tmp10_ = _data_->body;
	_data_->_state_ = 1;
	dino_ui_free_desktop_notifier_notify_content_item (_data_->self, _data_->conversation, _data_->conversation_display_name, _data_->participant_display_name, _data_->_tmp10_, dino_ui_free_desktop_notifier_notify_message_ready, _data_);
	return FALSE;
	_state_1:
	dino_ui_free_desktop_notifier_notify_content_item_finish (_data_->self, _data_->_res_);
	_g_free0 (_data_->body);
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!g_task_get_completed (_data_->_async_result)) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

static void
dino_ui_free_desktop_notifier_real_notify_file_data_free (gpointer _data)
{
	DinoUiFreeDesktopNotifierNotifyFileData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->file_transfer);
	_g_object_unref0 (_data_->conversation);
	_g_free0 (_data_->conversation_display_name);
	_g_free0 (_data_->participant_display_name);
	_g_object_unref0 (_data_->self);
	g_slice_free (DinoUiFreeDesktopNotifierNotifyFileData, _data_);
}

static void
dino_ui_free_desktop_notifier_real_notify_file (DinoNotificationProvider* base,
                                                DinoEntitiesFileTransfer* file_transfer,
                                                DinoEntitiesConversation* conversation,
                                                gboolean is_image,
                                                const gchar* conversation_display_name,
                                                const gchar* participant_display_name,
                                                GAsyncReadyCallback _callback_,
                                                gpointer _user_data_)
{
	DinoUiFreeDesktopNotifier * self;
	DinoUiFreeDesktopNotifierNotifyFileData* _data_;
	DinoUiFreeDesktopNotifier* _tmp0_;
	DinoEntitiesFileTransfer* _tmp1_;
	DinoEntitiesConversation* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	g_return_if_fail (file_transfer != NULL);
	g_return_if_fail (conversation != NULL);
	g_return_if_fail (conversation_display_name != NULL);
	self = (DinoUiFreeDesktopNotifier*) base;
	_data_ = g_slice_new0 (DinoUiFreeDesktopNotifierNotifyFileData);
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
	g_task_set_task_data (_data_->_async_result, _data_, dino_ui_free_desktop_notifier_real_notify_file_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = _g_object_ref0 (file_transfer);
	_g_object_unref0 (_data_->file_transfer);
	_data_->file_transfer = _tmp1_;
	_tmp2_ = _g_object_ref0 (conversation);
	_g_object_unref0 (_data_->conversation);
	_data_->conversation = _tmp2_;
	_data_->is_image = is_image;
	_tmp3_ = g_strdup (conversation_display_name);
	_g_free0 (_data_->conversation_display_name);
	_data_->conversation_display_name = _tmp3_;
	_tmp4_ = g_strdup (participant_display_name);
	_g_free0 (_data_->participant_display_name);
	_data_->participant_display_name = _tmp4_;
	dino_ui_free_desktop_notifier_real_notify_file_co (_data_);
}

static void
dino_ui_free_desktop_notifier_notify_file_finish (DinoNotificationProvider* base,
                                                  GAsyncResult* _res_)
{
	DinoUiFreeDesktopNotifierNotifyFileData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
}

static void
dino_ui_free_desktop_notifier_notify_file_ready (GObject* source_object,
                                                 GAsyncResult* _res_,
                                                 gpointer _user_data_)
{
	DinoUiFreeDesktopNotifierNotifyFileData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	dino_ui_free_desktop_notifier_real_notify_file_co (_data_);
}

static gboolean
dino_ui_free_desktop_notifier_real_notify_file_co (DinoUiFreeDesktopNotifierNotifyFileData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_tmp0_ = g_strdup ("");
	_data_->text = _data_->_tmp0_;
	_data_->_tmp1_ = dino_entities_file_transfer_get_direction (_data_->file_transfer);
	_data_->_tmp2_ = _data_->_tmp1_;
	if (_data_->_tmp2_ == DINO_ENTITIES_MESSAGE_DIRECTION_SENT) {
		if (_data_->is_image) {
			_data_->_tmp4_ = dino_gettext ("Image sent");
			_data_->_tmp3_ = _data_->_tmp4_;
		} else {
			_data_->_tmp5_ = dino_gettext ("File sent");
			_data_->_tmp3_ = _data_->_tmp5_;
		}
		_data_->_tmp6_ = g_strdup (_data_->_tmp3_);
		_g_free0 (_data_->text);
		_data_->text = _data_->_tmp6_;
	} else {
		if (_data_->is_image) {
			_data_->_tmp8_ = dino_gettext ("Image received");
			_data_->_tmp7_ = _data_->_tmp8_;
		} else {
			_data_->_tmp9_ = dino_gettext ("File received");
			_data_->_tmp7_ = _data_->_tmp9_;
		}
		_data_->_tmp10_ = g_strdup (_data_->_tmp7_);
		_g_free0 (_data_->text);
		_data_->text = _data_->_tmp10_;
	}
	if (_data_->self->priv->supports_body_markup) {
		_data_->_tmp11_ = _data_->text;
		_data_->_tmp12_ = g_strconcat ("<i>", _data_->_tmp11_, NULL);
		_data_->_tmp13_ = _data_->_tmp12_;
		_data_->_tmp14_ = g_strconcat (_data_->_tmp13_, "</i>", NULL);
		_g_free0 (_data_->text);
		_data_->text = _data_->_tmp14_;
		_g_free0 (_data_->_tmp13_);
	}
	_data_->_tmp15_ = _data_->text;
	_data_->_state_ = 1;
	dino_ui_free_desktop_notifier_notify_content_item (_data_->self, _data_->conversation, _data_->conversation_display_name, _data_->participant_display_name, _data_->_tmp15_, dino_ui_free_desktop_notifier_notify_file_ready, _data_);
	return FALSE;
	_state_1:
	dino_ui_free_desktop_notifier_notify_content_item_finish (_data_->self, _data_->_res_);
	_g_free0 (_data_->text);
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!g_task_get_completed (_data_->_async_result)) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

static void
dino_ui_free_desktop_notifier_notify_content_item_data_free (gpointer _data)
{
	DinoUiFreeDesktopNotifierNotifyContentItemData* _data_;
	_data_ = _data;
	_g_free0 (_data_->conversation_display_name);
	_g_free0 (_data_->participant_display_name);
	_g_free0 (_data_->body_);
	_g_object_unref0 (_data_->self);
	g_slice_free (DinoUiFreeDesktopNotifierNotifyContentItemData, _data_);
}

static void
dino_ui_free_desktop_notifier_notify_content_item (DinoUiFreeDesktopNotifier* self,
                                                   DinoEntitiesConversation* conversation,
                                                   const gchar* conversation_display_name,
                                                   const gchar* participant_display_name,
                                                   const gchar* body_,
                                                   GAsyncReadyCallback _callback_,
                                                   gpointer _user_data_)
{
	DinoUiFreeDesktopNotifierNotifyContentItemData* _data_;
	DinoUiFreeDesktopNotifier* _tmp0_;
	DinoEntitiesConversation* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (conversation != NULL);
	g_return_if_fail (conversation_display_name != NULL);
	g_return_if_fail (body_ != NULL);
	_data_ = g_slice_new0 (DinoUiFreeDesktopNotifierNotifyContentItemData);
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
	g_task_set_task_data (_data_->_async_result, _data_, dino_ui_free_desktop_notifier_notify_content_item_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = _g_object_ref0 (conversation);
	_g_object_unref0 (_data_->conversation);
	_data_->conversation = _tmp1_;
	_tmp2_ = g_strdup (conversation_display_name);
	_g_free0 (_data_->conversation_display_name);
	_data_->conversation_display_name = _tmp2_;
	_tmp3_ = g_strdup (participant_display_name);
	_g_free0 (_data_->participant_display_name);
	_data_->participant_display_name = _tmp3_;
	_tmp4_ = g_strdup (body_);
	_g_free0 (_data_->body_);
	_data_->body_ = _tmp4_;
	dino_ui_free_desktop_notifier_notify_content_item_co (_data_);
}

static void
dino_ui_free_desktop_notifier_notify_content_item_finish (DinoUiFreeDesktopNotifier* self,
                                                          GAsyncResult* _res_)
{
	DinoUiFreeDesktopNotifierNotifyContentItemData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
}

static Block63Data*
block63_data_ref (Block63Data* _data63_)
{
	g_atomic_int_inc (&_data63_->_ref_count_);
	return _data63_;
}

static void
block63_data_unref (void * _userdata_)
{
	Block63Data* _data63_;
	_data63_ = (Block63Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data63_->_ref_count_)) {
		DinoUiFreeDesktopNotifier* self;
		self = _data63_->self;
		_g_object_unref0 (_data63_->conversation);
		_g_object_unref0 (self);
		g_slice_free (Block63Data, _data63_);
	}
}

static const gchar*
string_to_string (const gchar* self)
{
	const gchar* result;
	g_return_val_if_fail (self != NULL, NULL);
	result = self;
	return result;
}

static void
_g_free0_ (gpointer var)
{
	var = (g_free (var), NULL);
}

static void
_g_variant_unref0_ (gpointer var)
{
	(var == NULL) ? NULL : (var = (g_variant_unref (var), NULL));
}

static void
dino_ui_free_desktop_notifier_notify_content_item_ready (GObject* source_object,
                                                         GAsyncResult* _res_,
                                                         gpointer _user_data_)
{
	DinoUiFreeDesktopNotifierNotifyContentItemData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	dino_ui_free_desktop_notifier_notify_content_item_co (_data_);
}

static void
___lambda320_ (Block63Data* _data63_)
{
	DinoUiFreeDesktopNotifier* self;
	GApplication* _tmp0_;
	gint _tmp1_;
	gint _tmp2_;
	GVariant* _tmp3_;
	GVariant* _tmp4_;
	self = _data63_->self;
	_tmp0_ = g_application_get_default ();
	_tmp1_ = dino_entities_conversation_get_id (_data63_->conversation);
	_tmp2_ = _tmp1_;
	_tmp3_ = g_variant_new_int32 ((gint32) _tmp2_);
	g_variant_ref_sink (_tmp3_);
	_tmp4_ = _tmp3_;
	g_action_group_activate_action ((GActionGroup*) _tmp0_, "open-conversation", _tmp4_);
	_g_variant_unref0 (_tmp4_);
}

static void
____lambda320__dino_ui_free_desktop_notifier_listener_func (gpointer self)
{
	___lambda320_ (self);
}

static gboolean
dino_ui_free_desktop_notifier_notify_content_item_co (DinoUiFreeDesktopNotifierNotifyContentItemData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		case 2:
		goto _state_2;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_data63_ = g_slice_new0 (Block63Data);
	_data_->_data63_->_ref_count_ = 1;
	_data_->_data63_->self = g_object_ref (_data_->self);
	_g_object_unref0 (_data_->_data63_->conversation);
	_data_->_data63_->conversation = _data_->conversation;
	_data_->_data63_->_async_data_ = _data_;
	_data_->_tmp0_ = g_strdup (_data_->body_);
	_data_->body = _data_->_tmp0_;
	if (_data_->participant_display_name != NULL) {
		if (_data_->self->priv->supports_body_markup) {
			_data_->_tmp1_ = g_markup_escape_text (_data_->participant_display_name, (gssize) -1);
			_data_->_tmp2_ = _data_->_tmp1_;
			_data_->_tmp3_ = string_to_string (_data_->_tmp2_);
			_data_->_tmp4_ = _data_->body;
			_data_->_tmp5_ = string_to_string (_data_->_tmp4_);
			_data_->_tmp6_ = g_strconcat ("<b>", _data_->_tmp3_, ":</b> ", _data_->_tmp5_, NULL);
			_g_free0 (_data_->body);
			_data_->body = _data_->_tmp6_;
			_g_free0 (_data_->_tmp2_);
		} else {
			_data_->_tmp7_ = string_to_string (_data_->participant_display_name);
			_data_->_tmp8_ = _data_->body;
			_data_->_tmp9_ = string_to_string (_data_->_tmp8_);
			_data_->_tmp10_ = g_strconcat (_data_->_tmp7_, ": ", _data_->_tmp9_, NULL);
			_g_free0 (_data_->body);
			_data_->body = _data_->_tmp10_;
		}
	}
	_data_->_tmp12_ = _data_->self->priv->content_notifications;
	if (gee_abstract_map_has_key ((GeeAbstractMap*) _data_->_tmp12_, _data_->_data63_->conversation)) {
		_data_->_tmp13_ = _data_->self->priv->content_notifications;
		_data_->_tmp14_ = gee_abstract_map_get ((GeeAbstractMap*) _data_->_tmp13_, _data_->_data63_->conversation);
		_data_->_tmp11_ = (guint32) ((guintptr) _data_->_tmp14_);
	} else {
		_data_->_tmp11_ = (guint32) 0;
	}
	_data_->replace_id = _data_->_tmp11_;
	_data_->_tmp15_ = g_hash_table_new_full (NULL, NULL, _g_free0_, _g_variant_unref0_);
	_data_->hash_table = _data_->_tmp15_;
	_data_->_tmp16_ = g_strdup ("image-data");
	_data_->_state_ = 1;
	dino_ui_free_desktop_notifier_get_conversation_icon (_data_->self, _data_->_data63_->conversation, dino_ui_free_desktop_notifier_notify_content_item_ready, _data_);
	return FALSE;
	_state_1:
	_data_->_tmp17_ = dino_ui_free_desktop_notifier_get_conversation_icon_finish (_data_->self, _data_->_res_);
	g_hash_table_insert (_data_->hash_table, _data_->_tmp16_, _data_->_tmp17_);
	_data_->_tmp18_ = g_strdup ("desktop-entry");
	_data_->_tmp19_ = dino_application_get_default ();
	_data_->_tmp20_ = g_application_get_application_id ((GApplication*) _data_->_tmp19_);
	_data_->_tmp21_ = g_variant_new_string (_data_->_tmp20_);
	g_variant_ref_sink (_data_->_tmp21_);
	g_hash_table_insert (_data_->hash_table, _data_->_tmp18_, _data_->_tmp21_);
	_data_->_tmp22_ = g_strdup ("category");
	_data_->_tmp23_ = g_variant_new_string ("im.received");
	g_variant_ref_sink (_data_->_tmp23_);
	g_hash_table_insert (_data_->hash_table, _data_->_tmp22_, _data_->_tmp23_);
	_data_->_tmp24_ = g_strdup ("default");
	_data_->_tmp25_ = g_strdup ("Open conversation");
	_data_->_tmp26_ = g_new0 (gchar*, 2 + 1);
	_data_->_tmp26_[0] = _data_->_tmp24_;
	_data_->_tmp26_[1] = _data_->_tmp25_;
	_data_->actions = _data_->_tmp26_;
	_data_->actions_length1 = 2;
	_data_->_actions_size_ = _data_->actions_length1;
	{
		_data_->_tmp27_ = _data_->self->priv->dbus_notifications;
		_data_->_tmp28_ = _data_->body;
		_data_->_state_ = 2;
		dino_dbus_notifications_notify (_data_->_tmp27_, "Dino", _data_->replace_id, "", _data_->conversation_display_name, _data_->_tmp28_, _data_->actions, (gint) _data_->actions_length1, _data_->hash_table, (gint32) -1, dino_ui_free_desktop_notifier_notify_content_item_ready, _data_);
		return FALSE;
		_state_2:
		_data_->notification_id = dino_dbus_notifications_notify_finish (_data_->_tmp27_, _data_->_res_, &_data_->_inner_error0_);
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
			goto __catch0_g_error;
		}
		_data_->_tmp29_ = _data_->self->priv->content_notifications;
		gee_abstract_map_set ((GeeAbstractMap*) _data_->_tmp29_, _data_->_data63_->conversation, (gpointer) ((guintptr) _data_->notification_id));
		dino_ui_free_desktop_notifier_add_action_listener (_data_->self, _data_->notification_id, "default", ____lambda320__dino_ui_free_desktop_notifier_listener_func, block63_data_ref (_data_->_data63_), block63_data_unref);
	}
	goto __finally0;
	__catch0_g_error:
	{
		_data_->e = _data_->_inner_error0_;
		_data_->_inner_error0_ = NULL;
		_data_->_tmp30_ = _data_->e;
		_data_->_tmp31_ = _data_->_tmp30_->message;
		g_warning ("notifier_freedesktop.vala:107: Failed showing content item notificatio" \
"n: %s", _data_->_tmp31_);
		_g_error_free0 (_data_->e);
	}
	__finally0:
	if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
		_data_->actions = (_vala_array_free (_data_->actions, _data_->actions_length1, (GDestroyNotify) g_free), NULL);
		_g_hash_table_unref0 (_data_->hash_table);
		_g_free0 (_data_->body);
		block63_data_unref (_data_->_data63_);
		_data_->_data63_ = NULL;
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error0_->message, g_quark_to_string (_data_->_inner_error0_->domain), _data_->_inner_error0_->code);
		g_clear_error (&_data_->_inner_error0_);
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	_data_->actions = (_vala_array_free (_data_->actions, _data_->actions_length1, (GDestroyNotify) g_free), NULL);
	_g_hash_table_unref0 (_data_->hash_table);
	_g_free0 (_data_->body);
	block63_data_unref (_data_->_data63_);
	_data_->_data63_ = NULL;
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!g_task_get_completed (_data_->_async_result)) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

static void
dino_ui_free_desktop_notifier_real_notify_call_data_free (gpointer _data)
{
	DinoUiFreeDesktopNotifierNotifyCallData* _data_;
	_data_ = _data;
	_g_free0 (_data_->conversation_display_name);
	_g_object_unref0 (_data_->self);
	g_slice_free (DinoUiFreeDesktopNotifierNotifyCallData, _data_);
}

static void
dino_ui_free_desktop_notifier_real_notify_call (DinoNotificationProvider* base,
                                                DinoEntitiesCall* call,
                                                DinoEntitiesConversation* conversation,
                                                gboolean video,
                                                gboolean multiparty,
                                                const gchar* conversation_display_name,
                                                GAsyncReadyCallback _callback_,
                                                gpointer _user_data_)
{
	DinoUiFreeDesktopNotifier * self;
	DinoUiFreeDesktopNotifierNotifyCallData* _data_;
	DinoUiFreeDesktopNotifier* _tmp0_;
	DinoEntitiesCall* _tmp1_;
	DinoEntitiesConversation* _tmp2_;
	gchar* _tmp3_;
	g_return_if_fail (call != NULL);
	g_return_if_fail (conversation != NULL);
	g_return_if_fail (conversation_display_name != NULL);
	self = (DinoUiFreeDesktopNotifier*) base;
	_data_ = g_slice_new0 (DinoUiFreeDesktopNotifierNotifyCallData);
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
	g_task_set_task_data (_data_->_async_result, _data_, dino_ui_free_desktop_notifier_real_notify_call_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = _g_object_ref0 (call);
	_g_object_unref0 (_data_->call);
	_data_->call = _tmp1_;
	_tmp2_ = _g_object_ref0 (conversation);
	_g_object_unref0 (_data_->conversation);
	_data_->conversation = _tmp2_;
	_data_->video = video;
	_data_->multiparty = multiparty;
	_tmp3_ = g_strdup (conversation_display_name);
	_g_free0 (_data_->conversation_display_name);
	_data_->conversation_display_name = _tmp3_;
	dino_ui_free_desktop_notifier_real_notify_call_co (_data_);
}

static void
dino_ui_free_desktop_notifier_notify_call_finish (DinoNotificationProvider* base,
                                                  GAsyncResult* _res_)
{
	DinoUiFreeDesktopNotifierNotifyCallData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
}

static Block64Data*
block64_data_ref (Block64Data* _data64_)
{
	g_atomic_int_inc (&_data64_->_ref_count_);
	return _data64_;
}

static void
block64_data_unref (void * _userdata_)
{
	Block64Data* _data64_;
	_data64_ = (Block64Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data64_->_ref_count_)) {
		DinoUiFreeDesktopNotifier* self;
		self = _data64_->self;
		_g_object_unref0 (_data64_->call);
		_g_object_unref0 (_data64_->conversation);
		_g_object_unref0 (self);
		g_slice_free (Block64Data, _data64_);
	}
}

static GVariant*
_variant_new4 (const gchar* value)
{
	return g_variant_ref_sink (g_variant_new_string (value));
}

static void
dino_ui_free_desktop_notifier_notify_call_ready (GObject* source_object,
                                                 GAsyncResult* _res_,
                                                 gpointer _user_data_)
{
	DinoUiFreeDesktopNotifierNotifyCallData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	dino_ui_free_desktop_notifier_real_notify_call_co (_data_);
}

static void
___lambda321_ (Block64Data* _data64_)
{
	DinoUiFreeDesktopNotifier* self;
	GApplication* _tmp0_;
	gint _tmp1_;
	gint _tmp2_;
	GVariant* _tmp3_;
	GVariant* _tmp4_;
	self = _data64_->self;
	_tmp0_ = g_application_get_default ();
	_tmp1_ = dino_entities_conversation_get_id (_data64_->conversation);
	_tmp2_ = _tmp1_;
	_tmp3_ = g_variant_new_int32 ((gint32) _tmp2_);
	g_variant_ref_sink (_tmp3_);
	_tmp4_ = _tmp3_;
	g_action_group_activate_action ((GActionGroup*) _tmp0_, "open-conversation", _tmp4_);
	_g_variant_unref0 (_tmp4_);
}

static void
____lambda321__dino_ui_free_desktop_notifier_listener_func (gpointer self)
{
	___lambda321_ (self);
}

static void
___lambda322_ (Block64Data* _data64_)
{
	DinoUiFreeDesktopNotifier* self;
	GVariant* variant = NULL;
	gint _tmp0_;
	gint _tmp1_;
	GVariant* _tmp2_;
	gint _tmp3_;
	gint _tmp4_;
	GVariant* _tmp5_;
	GVariant** _tmp6_;
	GVariant** _tmp7_;
	gint _tmp7__length1;
	GVariant* _tmp8_;
	GVariant* _tmp9_;
	GApplication* _tmp10_;
	self = _data64_->self;
	_tmp0_ = dino_entities_conversation_get_id (_data64_->conversation);
	_tmp1_ = _tmp0_;
	_tmp2_ = g_variant_new_int32 ((gint32) _tmp1_);
	g_variant_ref_sink (_tmp2_);
	_tmp3_ = dino_entities_call_get_id (_data64_->call);
	_tmp4_ = _tmp3_;
	_tmp5_ = g_variant_new_int32 ((gint32) _tmp4_);
	g_variant_ref_sink (_tmp5_);
	_tmp6_ = g_new0 (GVariant*, 2 + 1);
	_tmp6_[0] = _tmp2_;
	_tmp6_[1] = _tmp5_;
	_tmp7_ = _tmp6_;
	_tmp7__length1 = 2;
	_tmp8_ = g_variant_new_tuple (_tmp7_, 2);
	g_variant_ref_sink (_tmp8_);
	_tmp9_ = _tmp8_;
	_tmp7_ = (_vala_array_free (_tmp7_, _tmp7__length1, (GDestroyNotify) g_variant_unref), NULL);
	variant = _tmp9_;
	_tmp10_ = g_application_get_default ();
	g_action_group_activate_action ((GActionGroup*) _tmp10_, "reject-call", variant);
	_g_variant_unref0 (variant);
}

static void
____lambda322__dino_ui_free_desktop_notifier_listener_func (gpointer self)
{
	___lambda322_ (self);
}

static void
___lambda323_ (Block64Data* _data64_)
{
	DinoUiFreeDesktopNotifier* self;
	GVariant* variant = NULL;
	gint _tmp0_;
	gint _tmp1_;
	GVariant* _tmp2_;
	gint _tmp3_;
	gint _tmp4_;
	GVariant* _tmp5_;
	GVariant** _tmp6_;
	GVariant** _tmp7_;
	gint _tmp7__length1;
	GVariant* _tmp8_;
	GVariant* _tmp9_;
	GApplication* _tmp10_;
	self = _data64_->self;
	_tmp0_ = dino_entities_conversation_get_id (_data64_->conversation);
	_tmp1_ = _tmp0_;
	_tmp2_ = g_variant_new_int32 ((gint32) _tmp1_);
	g_variant_ref_sink (_tmp2_);
	_tmp3_ = dino_entities_call_get_id (_data64_->call);
	_tmp4_ = _tmp3_;
	_tmp5_ = g_variant_new_int32 ((gint32) _tmp4_);
	g_variant_ref_sink (_tmp5_);
	_tmp6_ = g_new0 (GVariant*, 2 + 1);
	_tmp6_[0] = _tmp2_;
	_tmp6_[1] = _tmp5_;
	_tmp7_ = _tmp6_;
	_tmp7__length1 = 2;
	_tmp8_ = g_variant_new_tuple (_tmp7_, 2);
	g_variant_ref_sink (_tmp8_);
	_tmp9_ = _tmp8_;
	_tmp7_ = (_vala_array_free (_tmp7_, _tmp7__length1, (GDestroyNotify) g_variant_unref), NULL);
	variant = _tmp9_;
	_tmp10_ = g_application_get_default ();
	g_action_group_activate_action ((GActionGroup*) _tmp10_, "accept-call", variant);
	_g_variant_unref0 (variant);
}

static void
____lambda323__dino_ui_free_desktop_notifier_listener_func (gpointer self)
{
	___lambda323_ (self);
}

static gboolean
dino_ui_free_desktop_notifier_real_notify_call_co (DinoUiFreeDesktopNotifierNotifyCallData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_data64_ = g_slice_new0 (Block64Data);
	_data_->_data64_->_ref_count_ = 1;
	_data_->_data64_->self = g_object_ref (_data_->self);
	_g_object_unref0 (_data_->_data64_->call);
	_data_->_data64_->call = _data_->call;
	_g_object_unref0 (_data_->_data64_->conversation);
	_data_->_data64_->conversation = _data_->conversation;
	_data_->_data64_->_async_data_ = _data_;
	_data_->_tmp0_ = dino_entities_call_get_account (_data_->_data64_->call);
	_data_->_tmp1_ = _data_->_tmp0_;
	_data_->_tmp2_ = dino_entities_account_get_bare_jid (_data_->_tmp1_);
	_data_->_tmp3_ = _data_->_tmp2_;
	_data_->_tmp4_ = _data_->_tmp3_;
	_data_->_tmp5_ = xmpp_jid_to_string (_data_->_tmp4_);
	_data_->_tmp6_ = _data_->_tmp5_;
	g_debug ("notifier_freedesktop.vala:112: [%s] Call notification", _data_->_tmp6_);
	_g_free0 (_data_->_tmp6_);
	_xmpp_jid_unref0 (_data_->_tmp4_);
	_data_->_tmp7_ = g_markup_escape_text (_data_->conversation_display_name, (gssize) -1);
	_data_->summary = _data_->_tmp7_;
	if (_data_->video) {
		_data_->_tmp9_ = dino_gettext ("Incoming video call");
		_data_->_tmp8_ = _data_->_tmp9_;
	} else {
		_data_->_tmp10_ = dino_gettext ("Incoming call");
		_data_->_tmp8_ = _data_->_tmp10_;
	}
	_data_->_tmp11_ = g_strdup (_data_->_tmp8_);
	_data_->body = _data_->_tmp11_;
	if (_data_->multiparty) {
		if (_data_->video) {
			_data_->_tmp13_ = dino_gettext ("Incoming video group call");
			_data_->_tmp12_ = _data_->_tmp13_;
		} else {
			_data_->_tmp14_ = dino_gettext ("Incoming group call");
			_data_->_tmp12_ = _data_->_tmp14_;
		}
		_data_->_tmp15_ = g_strdup (_data_->_tmp12_);
		_g_free0 (_data_->body);
		_data_->body = _data_->_tmp15_;
	}
	_data_->_tmp16_ = g_hash_table_new_full (NULL, NULL, _g_free0_, _g_variant_unref0_);
	_data_->hash_table = _data_->_tmp16_;
	_data_->_tmp17_ = g_strdup ("image-path");
	_data_->_tmp18_ = _variant_new4 ("call-start-symbolic");
	g_hash_table_insert (_data_->hash_table, _data_->_tmp17_, _data_->_tmp18_);
	_data_->_tmp19_ = g_strdup ("sound-name");
	_data_->_tmp20_ = g_variant_new_string ("phone-incoming-call");
	g_variant_ref_sink (_data_->_tmp20_);
	g_hash_table_insert (_data_->hash_table, _data_->_tmp19_, _data_->_tmp20_);
	_data_->_tmp21_ = g_strdup ("urgency");
	_data_->_tmp22_ = g_variant_new_byte ((guint8) 2);
	g_variant_ref_sink (_data_->_tmp22_);
	g_hash_table_insert (_data_->hash_table, _data_->_tmp21_, _data_->_tmp22_);
	_data_->_tmp23_ = g_strdup ("desktop-entry");
	_data_->_tmp24_ = dino_application_get_default ();
	_data_->_tmp25_ = g_application_get_application_id ((GApplication*) _data_->_tmp24_);
	_data_->_tmp26_ = g_variant_new_string (_data_->_tmp25_);
	g_variant_ref_sink (_data_->_tmp26_);
	g_hash_table_insert (_data_->hash_table, _data_->_tmp23_, _data_->_tmp26_);
	_data_->_tmp27_ = g_strdup ("category");
	_data_->_tmp28_ = g_variant_new_string ("call.incoming");
	g_variant_ref_sink (_data_->_tmp28_);
	g_hash_table_insert (_data_->hash_table, _data_->_tmp27_, _data_->_tmp28_);
	_data_->_tmp29_ = g_strdup ("default");
	_data_->_tmp30_ = g_strdup ("Open conversation");
	_data_->_tmp31_ = g_strdup ("reject");
	_data_->_tmp32_ = dino_gettext ("Reject");
	_data_->_tmp33_ = g_strdup (_data_->_tmp32_);
	_data_->_tmp34_ = g_strdup ("accept");
	_data_->_tmp35_ = dino_gettext ("Accept");
	_data_->_tmp36_ = g_strdup (_data_->_tmp35_);
	_data_->_tmp37_ = g_new0 (gchar*, 6 + 1);
	_data_->_tmp37_[0] = _data_->_tmp29_;
	_data_->_tmp37_[1] = _data_->_tmp30_;
	_data_->_tmp37_[2] = _data_->_tmp31_;
	_data_->_tmp37_[3] = _data_->_tmp33_;
	_data_->_tmp37_[4] = _data_->_tmp34_;
	_data_->_tmp37_[5] = _data_->_tmp36_;
	_data_->actions = _data_->_tmp37_;
	_data_->actions_length1 = 6;
	_data_->_actions_size_ = _data_->actions_length1;
	{
		_data_->_tmp38_ = _data_->self->priv->dbus_notifications;
		_data_->_tmp39_ = _data_->summary;
		_data_->_tmp40_ = _data_->body;
		_data_->_state_ = 1;
		dino_dbus_notifications_notify (_data_->_tmp38_, "Dino", (guint32) 0, "", _data_->_tmp39_, _data_->_tmp40_, _data_->actions, (gint) _data_->actions_length1, _data_->hash_table, (gint32) 0, dino_ui_free_desktop_notifier_notify_call_ready, _data_);
		return FALSE;
		_state_1:
		_data_->notification_id = dino_dbus_notifications_notify_finish (_data_->_tmp38_, _data_->_res_, &_data_->_inner_error0_);
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
			goto __catch0_g_error;
		}
		_data_->_tmp41_ = _data_->self->priv->call_notifications;
		gee_abstract_map_set ((GeeAbstractMap*) _data_->_tmp41_, _data_->_data64_->call, (gpointer) ((guintptr) _data_->notification_id));
		dino_ui_free_desktop_notifier_add_action_listener (_data_->self, _data_->notification_id, "default", ____lambda321__dino_ui_free_desktop_notifier_listener_func, block64_data_ref (_data_->_data64_), block64_data_unref);
		dino_ui_free_desktop_notifier_add_action_listener (_data_->self, _data_->notification_id, "reject", ____lambda322__dino_ui_free_desktop_notifier_listener_func, block64_data_ref (_data_->_data64_), block64_data_unref);
		dino_ui_free_desktop_notifier_add_action_listener (_data_->self, _data_->notification_id, "accept", ____lambda323__dino_ui_free_desktop_notifier_listener_func, block64_data_ref (_data_->_data64_), block64_data_unref);
	}
	goto __finally0;
	__catch0_g_error:
	{
		_data_->e = _data_->_inner_error0_;
		_data_->_inner_error0_ = NULL;
		_data_->_tmp42_ = _data_->e;
		_data_->_tmp43_ = _data_->_tmp42_->message;
		g_warning ("notifier_freedesktop.vala:142: Failed showing subscription request not" \
"ification: %s", _data_->_tmp43_);
		_g_error_free0 (_data_->e);
	}
	__finally0:
	if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
		_data_->actions = (_vala_array_free (_data_->actions, _data_->actions_length1, (GDestroyNotify) g_free), NULL);
		_g_hash_table_unref0 (_data_->hash_table);
		_g_free0 (_data_->body);
		_g_free0 (_data_->summary);
		block64_data_unref (_data_->_data64_);
		_data_->_data64_ = NULL;
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error0_->message, g_quark_to_string (_data_->_inner_error0_->domain), _data_->_inner_error0_->code);
		g_clear_error (&_data_->_inner_error0_);
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	_data_->actions = (_vala_array_free (_data_->actions, _data_->actions_length1, (GDestroyNotify) g_free), NULL);
	_g_hash_table_unref0 (_data_->hash_table);
	_g_free0 (_data_->body);
	_g_free0 (_data_->summary);
	block64_data_unref (_data_->_data64_);
	_data_->_data64_ = NULL;
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!g_task_get_completed (_data_->_async_result)) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

static void
dino_ui_free_desktop_notifier_real_retract_call_notification_data_free (gpointer _data)
{
	DinoUiFreeDesktopNotifierRetractCallNotificationData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->call);
	_g_object_unref0 (_data_->conversation);
	_g_object_unref0 (_data_->self);
	g_slice_free (DinoUiFreeDesktopNotifierRetractCallNotificationData, _data_);
}

static void
dino_ui_free_desktop_notifier_real_retract_call_notification (DinoNotificationProvider* base,
                                                              DinoEntitiesCall* call,
                                                              DinoEntitiesConversation* conversation,
                                                              GAsyncReadyCallback _callback_,
                                                              gpointer _user_data_)
{
	DinoUiFreeDesktopNotifier * self;
	DinoUiFreeDesktopNotifierRetractCallNotificationData* _data_;
	DinoUiFreeDesktopNotifier* _tmp0_;
	DinoEntitiesCall* _tmp1_;
	DinoEntitiesConversation* _tmp2_;
	g_return_if_fail (call != NULL);
	g_return_if_fail (conversation != NULL);
	self = (DinoUiFreeDesktopNotifier*) base;
	_data_ = g_slice_new0 (DinoUiFreeDesktopNotifierRetractCallNotificationData);
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
	g_task_set_task_data (_data_->_async_result, _data_, dino_ui_free_desktop_notifier_real_retract_call_notification_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = _g_object_ref0 (call);
	_g_object_unref0 (_data_->call);
	_data_->call = _tmp1_;
	_tmp2_ = _g_object_ref0 (conversation);
	_g_object_unref0 (_data_->conversation);
	_data_->conversation = _tmp2_;
	dino_ui_free_desktop_notifier_real_retract_call_notification_co (_data_);
}

static void
dino_ui_free_desktop_notifier_retract_call_notification_finish (DinoNotificationProvider* base,
                                                                GAsyncResult* _res_)
{
	DinoUiFreeDesktopNotifierRetractCallNotificationData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
}

static void
dino_ui_free_desktop_notifier_retract_call_notification_ready (GObject* source_object,
                                                               GAsyncResult* _res_,
                                                               gpointer _user_data_)
{
	DinoUiFreeDesktopNotifierRetractCallNotificationData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	dino_ui_free_desktop_notifier_real_retract_call_notification_co (_data_);
}

static gboolean
dino_ui_free_desktop_notifier_real_retract_call_notification_co (DinoUiFreeDesktopNotifierRetractCallNotificationData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_tmp0_ = _data_->self->priv->call_notifications;
	if (!gee_abstract_map_has_key ((GeeAbstractMap*) _data_->_tmp0_, _data_->call)) {
		g_task_return_pointer (_data_->_async_result, _data_, NULL);
		if (_data_->_state_ != 0) {
			while (!g_task_get_completed (_data_->_async_result)) {
				g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
			}
		}
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	_data_->_tmp1_ = _data_->self->priv->call_notifications;
	_data_->_tmp2_ = gee_abstract_map_get ((GeeAbstractMap*) _data_->_tmp1_, _data_->call);
	_data_->notification_id = (guint32) ((guintptr) _data_->_tmp2_);
	{
		_data_->_tmp3_ = _data_->self->priv->dbus_notifications;
		_data_->_state_ = 1;
		dino_dbus_notifications_close_notification (_data_->_tmp3_, (guint) _data_->notification_id, dino_ui_free_desktop_notifier_retract_call_notification_ready, _data_);
		return FALSE;
		_state_1:
		dino_dbus_notifications_close_notification_finish (_data_->_tmp3_, _data_->_res_, &_data_->_inner_error0_);
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
			goto __catch0_g_error;
		}
		_data_->_tmp4_ = _data_->self->priv->action_listeners;
		gee_abstract_map_unset ((GeeAbstractMap*) _data_->_tmp4_, (gpointer) ((guintptr) _data_->notification_id), NULL);
		_data_->_tmp5_ = _data_->self->priv->call_notifications;
		gee_abstract_map_unset ((GeeAbstractMap*) _data_->_tmp5_, _data_->call, NULL);
	}
	goto __finally0;
	__catch0_g_error:
	{
		g_clear_error (&_data_->_inner_error0_);
	}
	__finally0:
	if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error0_->message, g_quark_to_string (_data_->_inner_error0_->domain), _data_->_inner_error0_->code);
		g_clear_error (&_data_->_inner_error0_);
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!g_task_get_completed (_data_->_async_result)) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

static void
dino_ui_free_desktop_notifier_real_notify_subscription_request_data_free (gpointer _data)
{
	DinoUiFreeDesktopNotifierNotifySubscriptionRequestData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->self);
	g_slice_free (DinoUiFreeDesktopNotifierNotifySubscriptionRequestData, _data_);
}

static void
dino_ui_free_desktop_notifier_real_notify_subscription_request (DinoNotificationProvider* base,
                                                                DinoEntitiesConversation* conversation,
                                                                GAsyncReadyCallback _callback_,
                                                                gpointer _user_data_)
{
	DinoUiFreeDesktopNotifier * self;
	DinoUiFreeDesktopNotifierNotifySubscriptionRequestData* _data_;
	DinoUiFreeDesktopNotifier* _tmp0_;
	DinoEntitiesConversation* _tmp1_;
	g_return_if_fail (conversation != NULL);
	self = (DinoUiFreeDesktopNotifier*) base;
	_data_ = g_slice_new0 (DinoUiFreeDesktopNotifierNotifySubscriptionRequestData);
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
	g_task_set_task_data (_data_->_async_result, _data_, dino_ui_free_desktop_notifier_real_notify_subscription_request_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = _g_object_ref0 (conversation);
	_g_object_unref0 (_data_->conversation);
	_data_->conversation = _tmp1_;
	dino_ui_free_desktop_notifier_real_notify_subscription_request_co (_data_);
}

static void
dino_ui_free_desktop_notifier_notify_subscription_request_finish (DinoNotificationProvider* base,
                                                                  GAsyncResult* _res_)
{
	DinoUiFreeDesktopNotifierNotifySubscriptionRequestData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
}

static Block65Data*
block65_data_ref (Block65Data* _data65_)
{
	g_atomic_int_inc (&_data65_->_ref_count_);
	return _data65_;
}

static void
block65_data_unref (void * _userdata_)
{
	Block65Data* _data65_;
	_data65_ = (Block65Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data65_->_ref_count_)) {
		DinoUiFreeDesktopNotifier* self;
		self = _data65_->self;
		_g_object_unref0 (_data65_->conversation);
		_g_object_unref0 (self);
		g_slice_free (Block65Data, _data65_);
	}
}

static void
dino_ui_free_desktop_notifier_notify_subscription_request_ready (GObject* source_object,
                                                                 GAsyncResult* _res_,
                                                                 gpointer _user_data_)
{
	DinoUiFreeDesktopNotifierNotifySubscriptionRequestData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	dino_ui_free_desktop_notifier_real_notify_subscription_request_co (_data_);
}

static void
___lambda324_ (Block65Data* _data65_)
{
	DinoUiFreeDesktopNotifier* self;
	GApplication* _tmp0_;
	gint _tmp1_;
	gint _tmp2_;
	GVariant* _tmp3_;
	GVariant* _tmp4_;
	self = _data65_->self;
	_tmp0_ = g_application_get_default ();
	_tmp1_ = dino_entities_conversation_get_id (_data65_->conversation);
	_tmp2_ = _tmp1_;
	_tmp3_ = g_variant_new_int32 ((gint32) _tmp2_);
	g_variant_ref_sink (_tmp3_);
	_tmp4_ = _tmp3_;
	g_action_group_activate_action ((GActionGroup*) _tmp0_, "open-conversation", _tmp4_);
	_g_variant_unref0 (_tmp4_);
}

static void
____lambda324__dino_ui_free_desktop_notifier_listener_func (gpointer self)
{
	___lambda324_ (self);
}

static void
___lambda325_ (Block65Data* _data65_)
{
	DinoUiFreeDesktopNotifier* self;
	GApplication* _tmp0_;
	gint _tmp1_;
	gint _tmp2_;
	GVariant* _tmp3_;
	GVariant* _tmp4_;
	self = _data65_->self;
	_tmp0_ = g_application_get_default ();
	_tmp1_ = dino_entities_conversation_get_id (_data65_->conversation);
	_tmp2_ = _tmp1_;
	_tmp3_ = g_variant_new_int32 ((gint32) _tmp2_);
	g_variant_ref_sink (_tmp3_);
	_tmp4_ = _tmp3_;
	g_action_group_activate_action ((GActionGroup*) _tmp0_, "accept-subscription", _tmp4_);
	_g_variant_unref0 (_tmp4_);
}

static void
____lambda325__dino_ui_free_desktop_notifier_listener_func (gpointer self)
{
	___lambda325_ (self);
}

static void
___lambda326_ (Block65Data* _data65_)
{
	DinoUiFreeDesktopNotifier* self;
	GApplication* _tmp0_;
	gint _tmp1_;
	gint _tmp2_;
	GVariant* _tmp3_;
	GVariant* _tmp4_;
	self = _data65_->self;
	_tmp0_ = g_application_get_default ();
	_tmp1_ = dino_entities_conversation_get_id (_data65_->conversation);
	_tmp2_ = _tmp1_;
	_tmp3_ = g_variant_new_int32 ((gint32) _tmp2_);
	g_variant_ref_sink (_tmp3_);
	_tmp4_ = _tmp3_;
	g_action_group_activate_action ((GActionGroup*) _tmp0_, "deny-subscription", _tmp4_);
	_g_variant_unref0 (_tmp4_);
}

static void
____lambda326__dino_ui_free_desktop_notifier_listener_func (gpointer self)
{
	___lambda326_ (self);
}

static gboolean
dino_ui_free_desktop_notifier_real_notify_subscription_request_co (DinoUiFreeDesktopNotifierNotifySubscriptionRequestData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		case 2:
		goto _state_2;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_data65_ = g_slice_new0 (Block65Data);
	_data_->_data65_->_ref_count_ = 1;
	_data_->_data65_->self = g_object_ref (_data_->self);
	_g_object_unref0 (_data_->_data65_->conversation);
	_data_->_data65_->conversation = _data_->conversation;
	_data_->_data65_->_async_data_ = _data_;
	_data_->_tmp0_ = dino_gettext ("Subscription request");
	_data_->_tmp1_ = g_strdup (_data_->_tmp0_);
	_data_->summary = _data_->_tmp1_;
	_data_->_tmp2_ = dino_entities_conversation_get_counterpart (_data_->_data65_->conversation);
	_data_->_tmp3_ = _data_->_tmp2_;
	_data_->_tmp4_ = xmpp_jid_to_string (_data_->_tmp3_);
	_data_->_tmp5_ = _data_->_tmp4_;
	_data_->_tmp6_ = g_markup_escape_text (_data_->_tmp5_, (gssize) -1);
	_data_->_tmp7_ = _data_->_tmp6_;
	_g_free0 (_data_->_tmp5_);
	_data_->body = _data_->_tmp7_;
	_data_->_tmp8_ = g_hash_table_new_full (NULL, NULL, _g_free0_, _g_variant_unref0_);
	_data_->hash_table = _data_->_tmp8_;
	_data_->_tmp9_ = g_strdup ("image-data");
	_data_->_state_ = 1;
	dino_ui_free_desktop_notifier_get_conversation_icon (_data_->self, _data_->_data65_->conversation, dino_ui_free_desktop_notifier_notify_subscription_request_ready, _data_);
	return FALSE;
	_state_1:
	_data_->_tmp10_ = dino_ui_free_desktop_notifier_get_conversation_icon_finish (_data_->self, _data_->_res_);
	g_hash_table_insert (_data_->hash_table, _data_->_tmp9_, _data_->_tmp10_);
	_data_->_tmp11_ = g_strdup ("desktop-entry");
	_data_->_tmp12_ = dino_application_get_default ();
	_data_->_tmp13_ = g_application_get_application_id ((GApplication*) _data_->_tmp12_);
	_data_->_tmp14_ = g_variant_new_string (_data_->_tmp13_);
	g_variant_ref_sink (_data_->_tmp14_);
	g_hash_table_insert (_data_->hash_table, _data_->_tmp11_, _data_->_tmp14_);
	_data_->_tmp15_ = g_strdup ("category");
	_data_->_tmp16_ = g_variant_new_string ("im");
	g_variant_ref_sink (_data_->_tmp16_);
	g_hash_table_insert (_data_->hash_table, _data_->_tmp15_, _data_->_tmp16_);
	_data_->_tmp17_ = g_strdup ("default");
	_data_->_tmp18_ = g_strdup ("Open conversation");
	_data_->_tmp19_ = g_strdup ("accept");
	_data_->_tmp20_ = dino_gettext ("Accept");
	_data_->_tmp21_ = g_strdup (_data_->_tmp20_);
	_data_->_tmp22_ = g_strdup ("deny");
	_data_->_tmp23_ = dino_gettext ("Deny");
	_data_->_tmp24_ = g_strdup (_data_->_tmp23_);
	_data_->_tmp25_ = g_new0 (gchar*, 6 + 1);
	_data_->_tmp25_[0] = _data_->_tmp17_;
	_data_->_tmp25_[1] = _data_->_tmp18_;
	_data_->_tmp25_[2] = _data_->_tmp19_;
	_data_->_tmp25_[3] = _data_->_tmp21_;
	_data_->_tmp25_[4] = _data_->_tmp22_;
	_data_->_tmp25_[5] = _data_->_tmp24_;
	_data_->actions = _data_->_tmp25_;
	_data_->actions_length1 = 6;
	_data_->_actions_size_ = _data_->actions_length1;
	{
		_data_->_tmp26_ = _data_->self->priv->dbus_notifications;
		_data_->_state_ = 2;
		dino_dbus_notifications_notify (_data_->_tmp26_, "Dino", (guint32) 0, "", _data_->summary, _data_->body, _data_->actions, (gint) _data_->actions_length1, _data_->hash_table, (gint32) -1, dino_ui_free_desktop_notifier_notify_subscription_request_ready, _data_);
		return FALSE;
		_state_2:
		_data_->notification_id = dino_dbus_notifications_notify_finish (_data_->_tmp26_, _data_->_res_, &_data_->_inner_error0_);
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
			goto __catch0_g_error;
		}
		_data_->_tmp27_ = _data_->self->priv->conversation_notifications;
		if (!gee_abstract_map_has_key ((GeeAbstractMap*) _data_->_tmp27_, _data_->_data65_->conversation)) {
			_data_->_tmp28_ = _data_->self->priv->conversation_notifications;
			_data_->_tmp29_ = gee_array_list_new (G_TYPE_UINT, NULL, NULL, NULL, NULL, NULL);
			_data_->_tmp30_ = _data_->_tmp29_;
			gee_abstract_map_set ((GeeAbstractMap*) _data_->_tmp28_, _data_->_data65_->conversation, (GeeList*) _data_->_tmp30_);
			_g_object_unref0 (_data_->_tmp30_);
		}
		_data_->_tmp31_ = _data_->self->priv->conversation_notifications;
		_data_->_tmp32_ = gee_abstract_map_get ((GeeAbstractMap*) _data_->_tmp31_, _data_->_data65_->conversation);
		_data_->_tmp33_ = (GeeList*) _data_->_tmp32_;
		gee_collection_add ((GeeCollection*) _data_->_tmp33_, (gpointer) ((guintptr) _data_->notification_id));
		_g_object_unref0 (_data_->_tmp33_);
		dino_ui_free_desktop_notifier_add_action_listener (_data_->self, _data_->notification_id, "default", ____lambda324__dino_ui_free_desktop_notifier_listener_func, block65_data_ref (_data_->_data65_), block65_data_unref);
		dino_ui_free_desktop_notifier_add_action_listener (_data_->self, _data_->notification_id, "accept", ____lambda325__dino_ui_free_desktop_notifier_listener_func, block65_data_ref (_data_->_data65_), block65_data_unref);
		dino_ui_free_desktop_notifier_add_action_listener (_data_->self, _data_->notification_id, "deny", ____lambda326__dino_ui_free_desktop_notifier_listener_func, block65_data_ref (_data_->_data65_), block65_data_unref);
	}
	goto __finally0;
	__catch0_g_error:
	{
		_data_->e = _data_->_inner_error0_;
		_data_->_inner_error0_ = NULL;
		_data_->_tmp34_ = _data_->e;
		_data_->_tmp35_ = _data_->_tmp34_->message;
		g_warning ("notifier_freedesktop.vala:183: Failed showing subscription request not" \
"ification: %s", _data_->_tmp35_);
		_g_error_free0 (_data_->e);
	}
	__finally0:
	if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
		_data_->actions = (_vala_array_free (_data_->actions, _data_->actions_length1, (GDestroyNotify) g_free), NULL);
		_g_hash_table_unref0 (_data_->hash_table);
		_g_free0 (_data_->body);
		_g_free0 (_data_->summary);
		block65_data_unref (_data_->_data65_);
		_data_->_data65_ = NULL;
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error0_->message, g_quark_to_string (_data_->_inner_error0_->domain), _data_->_inner_error0_->code);
		g_clear_error (&_data_->_inner_error0_);
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	_data_->actions = (_vala_array_free (_data_->actions, _data_->actions_length1, (GDestroyNotify) g_free), NULL);
	_g_hash_table_unref0 (_data_->hash_table);
	_g_free0 (_data_->body);
	_g_free0 (_data_->summary);
	block65_data_unref (_data_->_data65_);
	_data_->_data65_ = NULL;
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!g_task_get_completed (_data_->_async_result)) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

static void
dino_ui_free_desktop_notifier_real_notify_connection_error_data_free (gpointer _data)
{
	DinoUiFreeDesktopNotifierNotifyConnectionErrorData* _data_;
	_data_ = _data;
	_dino_connection_manager_connection_error_unref0 (_data_->_error_);
	_g_object_unref0 (_data_->self);
	g_slice_free (DinoUiFreeDesktopNotifierNotifyConnectionErrorData, _data_);
}

static gpointer
_dino_connection_manager_connection_error_ref0 (gpointer self)
{
	return self ? dino_connection_manager_connection_error_ref (self) : NULL;
}

static void
dino_ui_free_desktop_notifier_real_notify_connection_error (DinoNotificationProvider* base,
                                                            DinoEntitiesAccount* account,
                                                            DinoConnectionManagerConnectionError* _error_,
                                                            GAsyncReadyCallback _callback_,
                                                            gpointer _user_data_)
{
	DinoUiFreeDesktopNotifier * self;
	DinoUiFreeDesktopNotifierNotifyConnectionErrorData* _data_;
	DinoUiFreeDesktopNotifier* _tmp0_;
	DinoEntitiesAccount* _tmp1_;
	DinoConnectionManagerConnectionError* _tmp2_;
	g_return_if_fail (account != NULL);
	g_return_if_fail (_error_ != NULL);
	self = (DinoUiFreeDesktopNotifier*) base;
	_data_ = g_slice_new0 (DinoUiFreeDesktopNotifierNotifyConnectionErrorData);
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
	g_task_set_task_data (_data_->_async_result, _data_, dino_ui_free_desktop_notifier_real_notify_connection_error_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = _g_object_ref0 (account);
	_g_object_unref0 (_data_->account);
	_data_->account = _tmp1_;
	_tmp2_ = _dino_connection_manager_connection_error_ref0 (_error_);
	_dino_connection_manager_connection_error_unref0 (_data_->_error_);
	_data_->_error_ = _tmp2_;
	dino_ui_free_desktop_notifier_real_notify_connection_error_co (_data_);
}

static void
dino_ui_free_desktop_notifier_notify_connection_error_finish (DinoNotificationProvider* base,
                                                              GAsyncResult* _res_)
{
	DinoUiFreeDesktopNotifierNotifyConnectionErrorData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
}

static Block66Data*
block66_data_ref (Block66Data* _data66_)
{
	g_atomic_int_inc (&_data66_->_ref_count_);
	return _data66_;
}

static void
block66_data_unref (void * _userdata_)
{
	Block66Data* _data66_;
	_data66_ = (Block66Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data66_->_ref_count_)) {
		DinoUiFreeDesktopNotifier* self;
		self = _data66_->self;
		_g_object_unref0 (_data66_->account);
		_g_object_unref0 (self);
		g_slice_free (Block66Data, _data66_);
	}
}

static void
dino_ui_free_desktop_notifier_notify_connection_error_ready (GObject* source_object,
                                                             GAsyncResult* _res_,
                                                             gpointer _user_data_)
{
	DinoUiFreeDesktopNotifierNotifyConnectionErrorData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	dino_ui_free_desktop_notifier_real_notify_connection_error_co (_data_);
}

static void
___lambda327_ (Block66Data* _data66_)
{
	DinoUiFreeDesktopNotifier* self;
	GApplication* _tmp0_;
	gint _tmp1_;
	gint _tmp2_;
	GVariant* _tmp3_;
	GVariant* _tmp4_;
	self = _data66_->self;
	_tmp0_ = g_application_get_default ();
	_tmp1_ = dino_entities_account_get_id (_data66_->account);
	_tmp2_ = _tmp1_;
	_tmp3_ = g_variant_new_int32 ((gint32) _tmp2_);
	g_variant_ref_sink (_tmp3_);
	_tmp4_ = _tmp3_;
	g_action_group_activate_action ((GActionGroup*) _tmp0_, "preferences-account", _tmp4_);
	_g_variant_unref0 (_tmp4_);
}

static void
____lambda327__dino_ui_free_desktop_notifier_listener_func (gpointer self)
{
	___lambda327_ (self);
}

static gboolean
dino_ui_free_desktop_notifier_real_notify_connection_error_co (DinoUiFreeDesktopNotifierNotifyConnectionErrorData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_data66_ = g_slice_new0 (Block66Data);
	_data_->_data66_->_ref_count_ = 1;
	_data_->_data66_->self = g_object_ref (_data_->self);
	_g_object_unref0 (_data_->_data66_->account);
	_data_->_data66_->account = _data_->account;
	_data_->_data66_->_async_data_ = _data_;
	_data_->_tmp0_ = dino_gettext ("Could not connect to %s");
	_data_->_tmp1_ = dino_entities_account_get_bare_jid (_data_->_data66_->account);
	_data_->_tmp2_ = _data_->_tmp1_;
	_data_->_tmp3_ = _data_->_tmp2_;
	_data_->_tmp4_ = _data_->_tmp3_->domainpart;
	_data_->_tmp5_ = g_strdup_printf (_data_->_tmp0_, _data_->_tmp4_);
	_data_->_tmp6_ = _data_->_tmp5_;
	_xmpp_jid_unref0 (_data_->_tmp3_);
	_data_->summary = _data_->_tmp6_;
	_data_->_tmp7_ = g_strdup ("");
	_data_->body = _data_->_tmp7_;
	switch (_data_->_error_->source) {
		case DINO_CONNECTION_MANAGER_CONNECTION_ERROR_SOURCE_SASL:
		{
			_data_->_tmp8_ = dino_gettext ("Wrong password");
			_data_->_tmp9_ = g_strdup (_data_->_tmp8_);
			_g_free0 (_data_->body);
			_data_->body = _data_->_tmp9_;
			break;
		}
		case DINO_CONNECTION_MANAGER_CONNECTION_ERROR_SOURCE_TLS:
		{
			_data_->_tmp10_ = dino_gettext ("Invalid TLS certificate");
			_data_->_tmp11_ = g_strdup (_data_->_tmp10_);
			_g_free0 (_data_->body);
			_data_->body = _data_->_tmp11_;
			break;
		}
		default:
		{
			break;
		}
	}
	_data_->_tmp12_ = g_hash_table_new_full (NULL, NULL, _g_free0_, _g_variant_unref0_);
	_data_->hash_table = _data_->_tmp12_;
	_data_->_tmp13_ = g_strdup ("desktop-entry");
	_data_->_tmp14_ = dino_application_get_default ();
	_data_->_tmp15_ = g_application_get_application_id ((GApplication*) _data_->_tmp14_);
	_data_->_tmp16_ = g_variant_new_string (_data_->_tmp15_);
	g_variant_ref_sink (_data_->_tmp16_);
	g_hash_table_insert (_data_->hash_table, _data_->_tmp13_, _data_->_tmp16_);
	_data_->_tmp17_ = g_strdup ("category");
	_data_->_tmp18_ = g_variant_new_string ("im.error");
	g_variant_ref_sink (_data_->_tmp18_);
	g_hash_table_insert (_data_->hash_table, _data_->_tmp17_, _data_->_tmp18_);
	_data_->_tmp19_ = g_strdup ("default");
	_data_->_tmp20_ = g_strdup ("Open preferences");
	_data_->_tmp21_ = g_new0 (gchar*, 2 + 1);
	_data_->_tmp21_[0] = _data_->_tmp19_;
	_data_->_tmp21_[1] = _data_->_tmp20_;
	_data_->actions = _data_->_tmp21_;
	_data_->actions_length1 = 2;
	_data_->_actions_size_ = _data_->actions_length1;
	{
		_data_->_tmp22_ = _data_->self->priv->dbus_notifications;
		_data_->_tmp23_ = _data_->summary;
		_data_->_tmp24_ = _data_->body;
		_data_->_state_ = 1;
		dino_dbus_notifications_notify (_data_->_tmp22_, "Dino", (guint32) 0, "im.dino.Dino", _data_->_tmp23_, _data_->_tmp24_, _data_->actions, (gint) _data_->actions_length1, _data_->hash_table, (gint32) -1, dino_ui_free_desktop_notifier_notify_connection_error_ready, _data_);
		return FALSE;
		_state_1:
		_data_->notification_id = dino_dbus_notifications_notify_finish (_data_->_tmp22_, _data_->_res_, &_data_->_inner_error0_);
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
			goto __catch0_g_error;
		}
		dino_ui_free_desktop_notifier_add_action_listener (_data_->self, _data_->notification_id, "default", ____lambda327__dino_ui_free_desktop_notifier_listener_func, block66_data_ref (_data_->_data66_), block66_data_unref);
	}
	goto __finally0;
	__catch0_g_error:
	{
		_data_->e = _data_->_inner_error0_;
		_data_->_inner_error0_ = NULL;
		_data_->_tmp25_ = _data_->e;
		_data_->_tmp26_ = _data_->_tmp25_->message;
		g_warning ("notifier_freedesktop.vala:212: Failed showing connection error notific" \
"ation: %s", _data_->_tmp26_);
		_g_error_free0 (_data_->e);
	}
	__finally0:
	if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
		_data_->actions = (_vala_array_free (_data_->actions, _data_->actions_length1, (GDestroyNotify) g_free), NULL);
		_g_hash_table_unref0 (_data_->hash_table);
		_g_free0 (_data_->body);
		_g_free0 (_data_->summary);
		block66_data_unref (_data_->_data66_);
		_data_->_data66_ = NULL;
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error0_->message, g_quark_to_string (_data_->_inner_error0_->domain), _data_->_inner_error0_->code);
		g_clear_error (&_data_->_inner_error0_);
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	_data_->actions = (_vala_array_free (_data_->actions, _data_->actions_length1, (GDestroyNotify) g_free), NULL);
	_g_hash_table_unref0 (_data_->hash_table);
	_g_free0 (_data_->body);
	_g_free0 (_data_->summary);
	block66_data_unref (_data_->_data66_);
	_data_->_data66_ = NULL;
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!g_task_get_completed (_data_->_async_result)) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

static void
dino_ui_free_desktop_notifier_real_notify_muc_invite_data_free (gpointer _data)
{
	DinoUiFreeDesktopNotifierNotifyMucInviteData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->account);
	_xmpp_jid_unref0 (_data_->room_jid);
	_xmpp_jid_unref0 (_data_->from_jid);
	_g_free0 (_data_->inviter_display_name);
	_g_object_unref0 (_data_->self);
	g_slice_free (DinoUiFreeDesktopNotifierNotifyMucInviteData, _data_);
}

static gpointer
_xmpp_jid_ref0 (gpointer self)
{
	return self ? xmpp_jid_ref (self) : NULL;
}

static void
dino_ui_free_desktop_notifier_real_notify_muc_invite (DinoNotificationProvider* base,
                                                      DinoEntitiesAccount* account,
                                                      XmppJid* room_jid,
                                                      XmppJid* from_jid,
                                                      const gchar* inviter_display_name,
                                                      GAsyncReadyCallback _callback_,
                                                      gpointer _user_data_)
{
	DinoUiFreeDesktopNotifier * self;
	DinoUiFreeDesktopNotifierNotifyMucInviteData* _data_;
	DinoUiFreeDesktopNotifier* _tmp0_;
	DinoEntitiesAccount* _tmp1_;
	XmppJid* _tmp2_;
	XmppJid* _tmp3_;
	gchar* _tmp4_;
	g_return_if_fail (account != NULL);
	g_return_if_fail (room_jid != NULL);
	g_return_if_fail (from_jid != NULL);
	g_return_if_fail (inviter_display_name != NULL);
	self = (DinoUiFreeDesktopNotifier*) base;
	_data_ = g_slice_new0 (DinoUiFreeDesktopNotifierNotifyMucInviteData);
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
	g_task_set_task_data (_data_->_async_result, _data_, dino_ui_free_desktop_notifier_real_notify_muc_invite_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = _g_object_ref0 (account);
	_g_object_unref0 (_data_->account);
	_data_->account = _tmp1_;
	_tmp2_ = _xmpp_jid_ref0 (room_jid);
	_xmpp_jid_unref0 (_data_->room_jid);
	_data_->room_jid = _tmp2_;
	_tmp3_ = _xmpp_jid_ref0 (from_jid);
	_xmpp_jid_unref0 (_data_->from_jid);
	_data_->from_jid = _tmp3_;
	_tmp4_ = g_strdup (inviter_display_name);
	_g_free0 (_data_->inviter_display_name);
	_data_->inviter_display_name = _tmp4_;
	dino_ui_free_desktop_notifier_real_notify_muc_invite_co (_data_);
}

static void
dino_ui_free_desktop_notifier_notify_muc_invite_finish (DinoNotificationProvider* base,
                                                        GAsyncResult* _res_)
{
	DinoUiFreeDesktopNotifierNotifyMucInviteData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
}

static void
dino_ui_free_desktop_notifier_notify_muc_invite_ready (GObject* source_object,
                                                       GAsyncResult* _res_,
                                                       gpointer _user_data_)
{
	DinoUiFreeDesktopNotifierNotifyMucInviteData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	dino_ui_free_desktop_notifier_real_notify_muc_invite_co (_data_);
}

static Block67Data*
block67_data_ref (Block67Data* _data67_)
{
	g_atomic_int_inc (&_data67_->_ref_count_);
	return _data67_;
}

static void
block67_data_unref (void * _userdata_)
{
	Block67Data* _data67_;
	_data67_ = (Block67Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data67_->_ref_count_)) {
		DinoUiFreeDesktopNotifier* self;
		self = _data67_->self;
		_g_object_unref0 (_data67_->group_conversation);
		_g_object_unref0 (self);
		g_slice_free (Block67Data, _data67_);
	}
}

static void
___lambda328_ (Block67Data* _data67_)
{
	DinoUiFreeDesktopNotifier* self;
	GApplication* _tmp0_;
	DinoEntitiesConversation* _tmp1_;
	gint _tmp2_;
	gint _tmp3_;
	GVariant* _tmp4_;
	GVariant* _tmp5_;
	self = _data67_->self;
	_tmp0_ = g_application_get_default ();
	_tmp1_ = _data67_->group_conversation;
	_tmp2_ = dino_entities_conversation_get_id (_tmp1_);
	_tmp3_ = _tmp2_;
	_tmp4_ = g_variant_new_int32 ((gint32) _tmp3_);
	g_variant_ref_sink (_tmp4_);
	_tmp5_ = _tmp4_;
	g_action_group_activate_action ((GActionGroup*) _tmp0_, "open-muc-join", _tmp5_);
	_g_variant_unref0 (_tmp5_);
}

static void
____lambda328__dino_ui_free_desktop_notifier_listener_func (gpointer self)
{
	___lambda328_ (self);
}

static void
___lambda329_ (Block67Data* _data67_)
{
	DinoUiFreeDesktopNotifier* self;
	GApplication* _tmp0_;
	DinoEntitiesConversation* _tmp1_;
	gint _tmp2_;
	gint _tmp3_;
	GVariant* _tmp4_;
	GVariant* _tmp5_;
	self = _data67_->self;
	_tmp0_ = g_application_get_default ();
	_tmp1_ = _data67_->group_conversation;
	_tmp2_ = dino_entities_conversation_get_id (_tmp1_);
	_tmp3_ = _tmp2_;
	_tmp4_ = g_variant_new_int32 ((gint32) _tmp3_);
	g_variant_ref_sink (_tmp4_);
	_tmp5_ = _tmp4_;
	g_action_group_activate_action ((GActionGroup*) _tmp0_, "open-muc-join", _tmp5_);
	_g_variant_unref0 (_tmp5_);
}

static void
____lambda329__dino_ui_free_desktop_notifier_listener_func (gpointer self)
{
	___lambda329_ (self);
}

static void
___lambda330_ (Block67Data* _data67_)
{
	DinoUiFreeDesktopNotifier* self;
	GApplication* _tmp0_;
	DinoEntitiesConversation* _tmp1_;
	gint _tmp2_;
	gint _tmp3_;
	GVariant* _tmp4_;
	GVariant* _tmp5_;
	self = _data67_->self;
	_tmp0_ = g_application_get_default ();
	_tmp1_ = _data67_->group_conversation;
	_tmp2_ = dino_entities_conversation_get_id (_tmp1_);
	_tmp3_ = _tmp2_;
	_tmp4_ = g_variant_new_int32 ((gint32) _tmp3_);
	g_variant_ref_sink (_tmp4_);
	_tmp5_ = _tmp4_;
	g_action_group_activate_action ((GActionGroup*) _tmp0_, "deny-invite", _tmp5_);
	_g_variant_unref0 (_tmp5_);
}

static void
____lambda330__dino_ui_free_desktop_notifier_listener_func (gpointer self)
{
	___lambda330_ (self);
}

static gboolean
dino_ui_free_desktop_notifier_real_notify_muc_invite_co (DinoUiFreeDesktopNotifierNotifyMucInviteData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		case 2:
		goto _state_2;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_tmp0_ = dino_entities_conversation_new (_data_->from_jid, _data_->account, DINO_ENTITIES_CONVERSATION_TYPE_CHAT);
	_data_->direct_conversation = _data_->_tmp0_;
	_data_->_tmp1_ = xmpp_jid_get_bare_jid (_data_->room_jid);
	_data_->_tmp2_ = _data_->_tmp1_;
	_data_->_tmp3_ = _data_->_tmp2_;
	_data_->_tmp4_ = xmpp_jid_to_string (_data_->_tmp3_);
	_data_->_tmp5_ = _data_->_tmp4_;
	_xmpp_jid_unref0 (_data_->_tmp3_);
	_data_->display_room = _data_->_tmp5_;
	_data_->_tmp6_ = dino_gettext ("Invitation to %s");
	_data_->_tmp7_ = _data_->display_room;
	_data_->_tmp8_ = g_strdup_printf (_data_->_tmp6_, _data_->_tmp7_);
	_data_->summary = _data_->_tmp8_;
	_data_->_tmp9_ = dino_gettext ("%s invited you to %s");
	_data_->_tmp10_ = _data_->display_room;
	_data_->_tmp11_ = g_strdup_printf (_data_->_tmp9_, _data_->inviter_display_name, _data_->_tmp10_);
	_data_->body = _data_->_tmp11_;
	if (_data_->self->priv->supports_body_markup) {
		_data_->_tmp12_ = _data_->body;
		_data_->_tmp13_ = g_markup_escape_text (_data_->_tmp12_, (gssize) -1);
		_g_free0 (_data_->body);
		_data_->body = _data_->_tmp13_;
	}
	_data_->_tmp14_ = g_hash_table_new_full (NULL, NULL, _g_free0_, _g_variant_unref0_);
	_data_->hash_table = _data_->_tmp14_;
	_data_->_tmp15_ = g_strdup ("image-data");
	_data_->_tmp16_ = _data_->direct_conversation;
	_data_->_state_ = 1;
	dino_ui_free_desktop_notifier_get_conversation_icon (_data_->self, _data_->_tmp16_, dino_ui_free_desktop_notifier_notify_muc_invite_ready, _data_);
	return FALSE;
	_state_1:
	_data_->_tmp17_ = dino_ui_free_desktop_notifier_get_conversation_icon_finish (_data_->self, _data_->_res_);
	g_hash_table_insert (_data_->hash_table, _data_->_tmp15_, _data_->_tmp17_);
	_data_->_tmp18_ = g_strdup ("desktop-entry");
	_data_->_tmp19_ = dino_application_get_default ();
	_data_->_tmp20_ = g_application_get_application_id ((GApplication*) _data_->_tmp19_);
	_data_->_tmp21_ = g_variant_new_string (_data_->_tmp20_);
	g_variant_ref_sink (_data_->_tmp21_);
	g_hash_table_insert (_data_->hash_table, _data_->_tmp18_, _data_->_tmp21_);
	_data_->_tmp22_ = g_strdup ("category");
	_data_->_tmp23_ = g_variant_new_string ("im");
	g_variant_ref_sink (_data_->_tmp23_);
	g_hash_table_insert (_data_->hash_table, _data_->_tmp22_, _data_->_tmp23_);
	_data_->_tmp24_ = g_strdup ("default");
	_data_->_tmp25_ = g_strdup ("");
	_data_->_tmp26_ = g_strdup ("reject");
	_data_->_tmp27_ = dino_gettext ("Reject");
	_data_->_tmp28_ = g_strdup (_data_->_tmp27_);
	_data_->_tmp29_ = g_strdup ("accept");
	_data_->_tmp30_ = dino_gettext ("Accept");
	_data_->_tmp31_ = g_strdup (_data_->_tmp30_);
	_data_->_tmp32_ = g_new0 (gchar*, 6 + 1);
	_data_->_tmp32_[0] = _data_->_tmp24_;
	_data_->_tmp32_[1] = _data_->_tmp25_;
	_data_->_tmp32_[2] = _data_->_tmp26_;
	_data_->_tmp32_[3] = _data_->_tmp28_;
	_data_->_tmp32_[4] = _data_->_tmp29_;
	_data_->_tmp32_[5] = _data_->_tmp31_;
	_data_->actions = _data_->_tmp32_;
	_data_->actions_length1 = 6;
	_data_->_actions_size_ = _data_->actions_length1;
	{
		_data_->_data67_ = g_slice_new0 (Block67Data);
		_data_->_data67_->_ref_count_ = 1;
		_data_->_data67_->self = g_object_ref (_data_->self);
		_data_->_tmp33_ = _data_->self->priv->dbus_notifications;
		_data_->_tmp34_ = _data_->summary;
		_data_->_tmp35_ = _data_->body;
		_data_->_state_ = 2;
		dino_dbus_notifications_notify (_data_->_tmp33_, "Dino", (guint32) 0, "", _data_->_tmp34_, _data_->_tmp35_, _data_->actions, (gint) _data_->actions_length1, _data_->hash_table, (gint32) -1, dino_ui_free_desktop_notifier_notify_muc_invite_ready, _data_);
		return FALSE;
		_state_2:
		_data_->notification_id = dino_dbus_notifications_notify_finish (_data_->_tmp33_, _data_->_res_, &_data_->_inner_error0_);
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
			block67_data_unref (_data_->_data67_);
			_data_->_data67_ = NULL;
			goto __catch0_g_error;
		}
		_data_->_tmp36_ = _data_->self->priv->stream_interactor;
		_data_->_tmp37_ = dino_conversation_manager_IDENTITY;
		_data_->_tmp38_ = dino_stream_interactor_get_module (_data_->_tmp36_, DINO_TYPE_CONVERSATION_MANAGER, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, _data_->_tmp37_);
		_data_->_tmp39_ = (DinoConversationManager*) _data_->_tmp38_;
		_data_->_tmp40_ = DINO_ENTITIES_CONVERSATION_TYPE_GROUPCHAT;
		_data_->_tmp41_ = dino_conversation_manager_create_conversation (_data_->_tmp39_, _data_->room_jid, _data_->account, &_data_->_tmp40_);
		_data_->_tmp42_ = _data_->_tmp41_;
		_g_object_unref0 (_data_->_tmp39_);
		_data_->_data67_->group_conversation = _data_->_tmp42_;
		dino_ui_free_desktop_notifier_add_action_listener (_data_->self, _data_->notification_id, "default", ____lambda328__dino_ui_free_desktop_notifier_listener_func, block67_data_ref (_data_->_data67_), block67_data_unref);
		dino_ui_free_desktop_notifier_add_action_listener (_data_->self, _data_->notification_id, "accept", ____lambda329__dino_ui_free_desktop_notifier_listener_func, block67_data_ref (_data_->_data67_), block67_data_unref);
		dino_ui_free_desktop_notifier_add_action_listener (_data_->self, _data_->notification_id, "deny", ____lambda330__dino_ui_free_desktop_notifier_listener_func, block67_data_ref (_data_->_data67_), block67_data_unref);
		block67_data_unref (_data_->_data67_);
		_data_->_data67_ = NULL;
	}
	goto __finally0;
	__catch0_g_error:
	{
		_data_->e = _data_->_inner_error0_;
		_data_->_inner_error0_ = NULL;
		_data_->_tmp43_ = _data_->e;
		_data_->_tmp44_ = _data_->_tmp43_->message;
		g_warning ("notifier_freedesktop.vala:246: Failed showing muc invite notification:" \
" %s", _data_->_tmp44_);
		_g_error_free0 (_data_->e);
	}
	__finally0:
	if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
		_data_->actions = (_vala_array_free (_data_->actions, _data_->actions_length1, (GDestroyNotify) g_free), NULL);
		_g_hash_table_unref0 (_data_->hash_table);
		_g_free0 (_data_->body);
		_g_free0 (_data_->summary);
		_g_free0 (_data_->display_room);
		_g_object_unref0 (_data_->direct_conversation);
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error0_->message, g_quark_to_string (_data_->_inner_error0_->domain), _data_->_inner_error0_->code);
		g_clear_error (&_data_->_inner_error0_);
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	_data_->actions = (_vala_array_free (_data_->actions, _data_->actions_length1, (GDestroyNotify) g_free), NULL);
	_g_hash_table_unref0 (_data_->hash_table);
	_g_free0 (_data_->body);
	_g_free0 (_data_->summary);
	_g_free0 (_data_->display_room);
	_g_object_unref0 (_data_->direct_conversation);
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!g_task_get_completed (_data_->_async_result)) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

static void
dino_ui_free_desktop_notifier_real_notify_voice_request_data_free (gpointer _data)
{
	DinoUiFreeDesktopNotifierNotifyVoiceRequestData* _data_;
	_data_ = _data;
	_xmpp_jid_unref0 (_data_->from_jid);
	_g_object_unref0 (_data_->self);
	g_slice_free (DinoUiFreeDesktopNotifierNotifyVoiceRequestData, _data_);
}

static void
dino_ui_free_desktop_notifier_real_notify_voice_request (DinoNotificationProvider* base,
                                                         DinoEntitiesConversation* conversation,
                                                         XmppJid* from_jid,
                                                         GAsyncReadyCallback _callback_,
                                                         gpointer _user_data_)
{
	DinoUiFreeDesktopNotifier * self;
	DinoUiFreeDesktopNotifierNotifyVoiceRequestData* _data_;
	DinoUiFreeDesktopNotifier* _tmp0_;
	DinoEntitiesConversation* _tmp1_;
	XmppJid* _tmp2_;
	g_return_if_fail (conversation != NULL);
	g_return_if_fail (from_jid != NULL);
	self = (DinoUiFreeDesktopNotifier*) base;
	_data_ = g_slice_new0 (DinoUiFreeDesktopNotifierNotifyVoiceRequestData);
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
	g_task_set_task_data (_data_->_async_result, _data_, dino_ui_free_desktop_notifier_real_notify_voice_request_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = _g_object_ref0 (conversation);
	_g_object_unref0 (_data_->conversation);
	_data_->conversation = _tmp1_;
	_tmp2_ = _xmpp_jid_ref0 (from_jid);
	_xmpp_jid_unref0 (_data_->from_jid);
	_data_->from_jid = _tmp2_;
	dino_ui_free_desktop_notifier_real_notify_voice_request_co (_data_);
}

static void
dino_ui_free_desktop_notifier_notify_voice_request_finish (DinoNotificationProvider* base,
                                                           GAsyncResult* _res_)
{
	DinoUiFreeDesktopNotifierNotifyVoiceRequestData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
}

static Block68Data*
block68_data_ref (Block68Data* _data68_)
{
	g_atomic_int_inc (&_data68_->_ref_count_);
	return _data68_;
}

static void
block68_data_unref (void * _userdata_)
{
	Block68Data* _data68_;
	_data68_ = (Block68Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data68_->_ref_count_)) {
		DinoUiFreeDesktopNotifier* self;
		self = _data68_->self;
		_g_object_unref0 (_data68_->conversation);
		_g_object_unref0 (self);
		g_slice_free (Block68Data, _data68_);
	}
}

static void
dino_ui_free_desktop_notifier_notify_voice_request_ready (GObject* source_object,
                                                          GAsyncResult* _res_,
                                                          gpointer _user_data_)
{
	DinoUiFreeDesktopNotifierNotifyVoiceRequestData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	dino_ui_free_desktop_notifier_real_notify_voice_request_co (_data_);
}

static void
___lambda331_ (Block68Data* _data68_)
{
	DinoUiFreeDesktopNotifier* self;
	GApplication* _tmp0_;
	gint _tmp1_;
	gint _tmp2_;
	GVariant* _tmp3_;
	GVariant* _tmp4_;
	self = _data68_->self;
	_tmp0_ = g_application_get_default ();
	_tmp1_ = dino_entities_conversation_get_id (_data68_->conversation);
	_tmp2_ = _tmp1_;
	_tmp3_ = g_variant_new_int32 ((gint32) _tmp2_);
	g_variant_ref_sink (_tmp3_);
	_tmp4_ = _tmp3_;
	g_action_group_activate_action ((GActionGroup*) _tmp0_, "accept-voice-request", _tmp4_);
	_g_variant_unref0 (_tmp4_);
}

static void
____lambda331__dino_ui_free_desktop_notifier_listener_func (gpointer self)
{
	___lambda331_ (self);
}

static void
___lambda332_ (Block68Data* _data68_)
{
	DinoUiFreeDesktopNotifier* self;
	GApplication* _tmp0_;
	gint _tmp1_;
	gint _tmp2_;
	GVariant* _tmp3_;
	GVariant* _tmp4_;
	self = _data68_->self;
	_tmp0_ = g_application_get_default ();
	_tmp1_ = dino_entities_conversation_get_id (_data68_->conversation);
	_tmp2_ = _tmp1_;
	_tmp3_ = g_variant_new_int32 ((gint32) _tmp2_);
	g_variant_ref_sink (_tmp3_);
	_tmp4_ = _tmp3_;
	g_action_group_activate_action ((GActionGroup*) _tmp0_, "deny-voice-request", _tmp4_);
	_g_variant_unref0 (_tmp4_);
}

static void
____lambda332__dino_ui_free_desktop_notifier_listener_func (gpointer self)
{
	___lambda332_ (self);
}

static gboolean
dino_ui_free_desktop_notifier_real_notify_voice_request_co (DinoUiFreeDesktopNotifierNotifyVoiceRequestData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		case 2:
		goto _state_2;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_data68_ = g_slice_new0 (Block68Data);
	_data_->_data68_->_ref_count_ = 1;
	_data_->_data68_->self = g_object_ref (_data_->self);
	_g_object_unref0 (_data_->_data68_->conversation);
	_data_->_data68_->conversation = _data_->conversation;
	_data_->_data68_->_async_data_ = _data_;
	_data_->_tmp0_ = _data_->self->priv->stream_interactor;
	_data_->_tmp1_ = dino_ui_util_get_participant_display_name (_data_->_tmp0_, _data_->_data68_->conversation, _data_->from_jid, FALSE);
	_data_->display_name = _data_->_tmp1_;
	_data_->_tmp2_ = _data_->self->priv->stream_interactor;
	_data_->_tmp3_ = dino_ui_util_get_conversation_display_name (_data_->_tmp2_, _data_->_data68_->conversation);
	_data_->display_room = _data_->_tmp3_;
	_data_->_tmp4_ = dino_gettext ("Permission request");
	_data_->_tmp5_ = g_strdup (_data_->_tmp4_);
	_data_->summary = _data_->_tmp5_;
	_data_->_tmp6_ = dino_gettext ("%s requests the permission to write in %s");
	_data_->_tmp7_ = _data_->display_name;
	_data_->_tmp8_ = _data_->display_room;
	_data_->_tmp9_ = g_strdup_printf (_data_->_tmp6_, _data_->_tmp7_, _data_->_tmp8_);
	_data_->body = _data_->_tmp9_;
	if (_data_->self->priv->supports_body_markup) {
		_data_->_tmp10_ = _data_->body;
		_data_->_tmp11_ = g_markup_escape_text (_data_->_tmp10_, (gssize) -1);
		_data_->_tmp12_ = _data_->_tmp11_;
		_g_free0 (_data_->_tmp12_);
	}
	_data_->_tmp13_ = g_hash_table_new_full (NULL, NULL, _g_free0_, _g_variant_unref0_);
	_data_->hash_table = _data_->_tmp13_;
	_data_->_tmp14_ = g_strdup ("image-data");
	_data_->_state_ = 1;
	dino_ui_free_desktop_notifier_get_conversation_icon (_data_->self, _data_->_data68_->conversation, dino_ui_free_desktop_notifier_notify_voice_request_ready, _data_);
	return FALSE;
	_state_1:
	_data_->_tmp15_ = dino_ui_free_desktop_notifier_get_conversation_icon_finish (_data_->self, _data_->_res_);
	g_hash_table_insert (_data_->hash_table, _data_->_tmp14_, _data_->_tmp15_);
	_data_->_tmp16_ = g_strdup ("desktop-entry");
	_data_->_tmp17_ = dino_application_get_default ();
	_data_->_tmp18_ = g_application_get_application_id ((GApplication*) _data_->_tmp17_);
	_data_->_tmp19_ = g_variant_new_string (_data_->_tmp18_);
	g_variant_ref_sink (_data_->_tmp19_);
	g_hash_table_insert (_data_->hash_table, _data_->_tmp16_, _data_->_tmp19_);
	_data_->_tmp20_ = g_strdup ("category");
	_data_->_tmp21_ = g_variant_new_string ("im");
	g_variant_ref_sink (_data_->_tmp21_);
	g_hash_table_insert (_data_->hash_table, _data_->_tmp20_, _data_->_tmp21_);
	_data_->_tmp22_ = g_strdup ("deny");
	_data_->_tmp23_ = dino_gettext ("Deny");
	_data_->_tmp24_ = g_strdup (_data_->_tmp23_);
	_data_->_tmp25_ = g_strdup ("accept");
	_data_->_tmp26_ = dino_gettext ("Accept");
	_data_->_tmp27_ = g_strdup (_data_->_tmp26_);
	_data_->_tmp28_ = g_new0 (gchar*, 4 + 1);
	_data_->_tmp28_[0] = _data_->_tmp22_;
	_data_->_tmp28_[1] = _data_->_tmp24_;
	_data_->_tmp28_[2] = _data_->_tmp25_;
	_data_->_tmp28_[3] = _data_->_tmp27_;
	_data_->actions = _data_->_tmp28_;
	_data_->actions_length1 = 4;
	_data_->_actions_size_ = _data_->actions_length1;
	{
		_data_->_tmp29_ = _data_->self->priv->dbus_notifications;
		_data_->_tmp30_ = _data_->summary;
		_data_->_tmp31_ = _data_->body;
		_data_->_state_ = 2;
		dino_dbus_notifications_notify (_data_->_tmp29_, "Dino", (guint32) 0, "", _data_->_tmp30_, _data_->_tmp31_, _data_->actions, (gint) _data_->actions_length1, _data_->hash_table, (gint32) -1, dino_ui_free_desktop_notifier_notify_voice_request_ready, _data_);
		return FALSE;
		_state_2:
		_data_->notification_id = dino_dbus_notifications_notify_finish (_data_->_tmp29_, _data_->_res_, &_data_->_inner_error0_);
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
			goto __catch0_g_error;
		}
		dino_ui_free_desktop_notifier_add_action_listener (_data_->self, _data_->notification_id, "accept", ____lambda331__dino_ui_free_desktop_notifier_listener_func, block68_data_ref (_data_->_data68_), block68_data_unref);
		dino_ui_free_desktop_notifier_add_action_listener (_data_->self, _data_->notification_id, "deny", ____lambda332__dino_ui_free_desktop_notifier_listener_func, block68_data_ref (_data_->_data68_), block68_data_unref);
	}
	goto __finally0;
	__catch0_g_error:
	{
		_data_->e = _data_->_inner_error0_;
		_data_->_inner_error0_ = NULL;
		_data_->_tmp32_ = _data_->e;
		_data_->_tmp33_ = _data_->_tmp32_->message;
		g_warning ("notifier_freedesktop.vala:276: Failed showing voice request notificati" \
"on: %s", _data_->_tmp33_);
		_g_error_free0 (_data_->e);
	}
	__finally0:
	if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
		_data_->actions = (_vala_array_free (_data_->actions, _data_->actions_length1, (GDestroyNotify) g_free), NULL);
		_g_hash_table_unref0 (_data_->hash_table);
		_g_free0 (_data_->body);
		_g_free0 (_data_->summary);
		_g_free0 (_data_->display_room);
		_g_free0 (_data_->display_name);
		block68_data_unref (_data_->_data68_);
		_data_->_data68_ = NULL;
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error0_->message, g_quark_to_string (_data_->_inner_error0_->domain), _data_->_inner_error0_->code);
		g_clear_error (&_data_->_inner_error0_);
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	_data_->actions = (_vala_array_free (_data_->actions, _data_->actions_length1, (GDestroyNotify) g_free), NULL);
	_g_hash_table_unref0 (_data_->hash_table);
	_g_free0 (_data_->body);
	_g_free0 (_data_->summary);
	_g_free0 (_data_->display_room);
	_g_free0 (_data_->display_name);
	block68_data_unref (_data_->_data68_);
	_data_->_data68_ = NULL;
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!g_task_get_completed (_data_->_async_result)) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

static void
dino_ui_free_desktop_notifier_real_retract_content_item_notifications_data_free (gpointer _data)
{
	DinoUiFreeDesktopNotifierRetractContentItemNotificationsData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->self);
	g_slice_free (DinoUiFreeDesktopNotifierRetractContentItemNotificationsData, _data_);
}

static void
dino_ui_free_desktop_notifier_real_retract_content_item_notifications (DinoNotificationProvider* base,
                                                                       GAsyncReadyCallback _callback_,
                                                                       gpointer _user_data_)
{
	DinoUiFreeDesktopNotifier * self;
	DinoUiFreeDesktopNotifierRetractContentItemNotificationsData* _data_;
	DinoUiFreeDesktopNotifier* _tmp0_;
	self = (DinoUiFreeDesktopNotifier*) base;
	_data_ = g_slice_new0 (DinoUiFreeDesktopNotifierRetractContentItemNotificationsData);
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
	g_task_set_task_data (_data_->_async_result, _data_, dino_ui_free_desktop_notifier_real_retract_content_item_notifications_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	dino_ui_free_desktop_notifier_real_retract_content_item_notifications_co (_data_);
}

static void
dino_ui_free_desktop_notifier_retract_content_item_notifications_finish (DinoNotificationProvider* base,
                                                                         GAsyncResult* _res_)
{
	DinoUiFreeDesktopNotifierRetractContentItemNotificationsData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
}

static gboolean
dino_ui_free_desktop_notifier_real_retract_content_item_notifications_co (DinoUiFreeDesktopNotifierRetractContentItemNotificationsData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	{
		_data_->_tmp0_ = _data_->self->priv->content_notifications;
		_data_->_tmp1_ = gee_abstract_map_get_values ((GeeAbstractMap*) _data_->_tmp0_);
		_data_->_tmp2_ = _data_->_tmp1_;
		_data_->_tmp3_ = _data_->_tmp2_;
		_data_->_tmp4_ = gee_iterable_iterator ((GeeIterable*) _data_->_tmp3_);
		_data_->_tmp5_ = _data_->_tmp4_;
		_g_object_unref0 (_data_->_tmp3_);
		_data_->_id_it = _data_->_tmp5_;
		while (TRUE) {
			_data_->_tmp6_ = _data_->_id_it;
			if (!gee_iterator_next (_data_->_tmp6_)) {
				break;
			}
			_data_->_tmp7_ = _data_->_id_it;
			_data_->_tmp8_ = gee_iterator_get (_data_->_tmp7_);
			_data_->id = (guint32) ((guintptr) _data_->_tmp8_);
			{
				_data_->_tmp9_ = _data_->self->priv->dbus_notifications;
				dino_dbus_notifications_close_notification (_data_->_tmp9_, (guint) _data_->id, NULL, NULL);
			}
			goto __finally0;
			__catch0_g_error:
			{
				g_clear_error (&_data_->_inner_error0_);
			}
			__finally0:
			if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
				_g_object_unref0 (_data_->_id_it);
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error0_->message, g_quark_to_string (_data_->_inner_error0_->domain), _data_->_inner_error0_->code);
				g_clear_error (&_data_->_inner_error0_);
				g_object_unref (_data_->_async_result);
				return FALSE;
			}
		}
		_g_object_unref0 (_data_->_id_it);
	}
	_data_->_tmp10_ = _data_->self->priv->content_notifications;
	gee_abstract_map_clear ((GeeAbstractMap*) _data_->_tmp10_);
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!g_task_get_completed (_data_->_async_result)) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

static void
dino_ui_free_desktop_notifier_real_retract_conversation_notifications_data_free (gpointer _data)
{
	DinoUiFreeDesktopNotifierRetractConversationNotificationsData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->conversation);
	_g_object_unref0 (_data_->self);
	g_slice_free (DinoUiFreeDesktopNotifierRetractConversationNotificationsData, _data_);
}

static void
dino_ui_free_desktop_notifier_real_retract_conversation_notifications (DinoNotificationProvider* base,
                                                                       DinoEntitiesConversation* conversation,
                                                                       GAsyncReadyCallback _callback_,
                                                                       gpointer _user_data_)
{
	DinoUiFreeDesktopNotifier * self;
	DinoUiFreeDesktopNotifierRetractConversationNotificationsData* _data_;
	DinoUiFreeDesktopNotifier* _tmp0_;
	DinoEntitiesConversation* _tmp1_;
	g_return_if_fail (conversation != NULL);
	self = (DinoUiFreeDesktopNotifier*) base;
	_data_ = g_slice_new0 (DinoUiFreeDesktopNotifierRetractConversationNotificationsData);
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
	g_task_set_task_data (_data_->_async_result, _data_, dino_ui_free_desktop_notifier_real_retract_conversation_notifications_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = _g_object_ref0 (conversation);
	_g_object_unref0 (_data_->conversation);
	_data_->conversation = _tmp1_;
	dino_ui_free_desktop_notifier_real_retract_conversation_notifications_co (_data_);
}

static void
dino_ui_free_desktop_notifier_retract_conversation_notifications_finish (DinoNotificationProvider* base,
                                                                         GAsyncResult* _res_)
{
	DinoUiFreeDesktopNotifierRetractConversationNotificationsData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
}

static gboolean
dino_ui_free_desktop_notifier_real_retract_conversation_notifications_co (DinoUiFreeDesktopNotifierRetractConversationNotificationsData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	{
		_data_->_tmp0_ = _data_->self->priv->content_notifications;
		if (gee_abstract_map_has_key ((GeeAbstractMap*) _data_->_tmp0_, _data_->conversation)) {
			_data_->_tmp1_ = _data_->self->priv->dbus_notifications;
			_data_->_tmp2_ = _data_->self->priv->content_notifications;
			_data_->_tmp3_ = gee_abstract_map_get ((GeeAbstractMap*) _data_->_tmp2_, _data_->conversation);
			dino_dbus_notifications_close_notification (_data_->_tmp1_, (guint) ((guint32) ((guintptr) _data_->_tmp3_)), NULL, NULL);
			_data_->_tmp4_ = _data_->self->priv->content_notifications;
			gee_abstract_map_unset ((GeeAbstractMap*) _data_->_tmp4_, _data_->conversation, NULL);
		}
		_data_->_tmp5_ = _data_->self->priv->conversation_notifications;
		if (gee_abstract_map_has_key ((GeeAbstractMap*) _data_->_tmp5_, _data_->conversation)) {
			{
				_data_->_tmp6_ = _data_->self->priv->conversation_notifications;
				_data_->_tmp7_ = gee_abstract_map_get ((GeeAbstractMap*) _data_->_tmp6_, _data_->conversation);
				_data_->_notification_id_list = (GeeList*) _data_->_tmp7_;
				_data_->_tmp8_ = _data_->_notification_id_list;
				_data_->_tmp9_ = gee_collection_get_size ((GeeCollection*) _data_->_tmp8_);
				_data_->_tmp10_ = _data_->_tmp9_;
				_data_->_notification_id_size = _data_->_tmp10_;
				_data_->_notification_id_index = -1;
				while (TRUE) {
					_data_->_notification_id_index = _data_->_notification_id_index + 1;
					_data_->_tmp11_ = _data_->_notification_id_index;
					_data_->_tmp12_ = _data_->_notification_id_size;
					if (!(_data_->_tmp11_ < _data_->_tmp12_)) {
						break;
					}
					_data_->_tmp13_ = _data_->_notification_id_list;
					_data_->_tmp14_ = gee_list_get (_data_->_tmp13_, _data_->_notification_id_index);
					_data_->notification_id = (guint32) ((guintptr) _data_->_tmp14_);
					_data_->_tmp15_ = _data_->self->priv->dbus_notifications;
					dino_dbus_notifications_close_notification (_data_->_tmp15_, (guint) _data_->notification_id, NULL, NULL);
				}
				_g_object_unref0 (_data_->_notification_id_list);
			}
			_data_->_tmp16_ = _data_->self->priv->conversation_notifications;
			gee_abstract_map_unset ((GeeAbstractMap*) _data_->_tmp16_, _data_->conversation, NULL);
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
		g_clear_error (&_data_->_inner_error0_);
	}
	__finally0:
	if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error0_->message, g_quark_to_string (_data_->_inner_error0_->domain), _data_->_inner_error0_->code);
		g_clear_error (&_data_->_inner_error0_);
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!g_task_get_completed (_data_->_async_result)) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

static void
dino_ui_free_desktop_notifier_get_conversation_icon_data_free (gpointer _data)
{
	DinoUiFreeDesktopNotifierGetConversationIconData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->conversation);
	_g_variant_unref0 (_data_->result);
	_g_object_unref0 (_data_->self);
	g_slice_free (DinoUiFreeDesktopNotifierGetConversationIconData, _data_);
}

static void
dino_ui_free_desktop_notifier_get_conversation_icon (DinoUiFreeDesktopNotifier* self,
                                                     DinoEntitiesConversation* conversation,
                                                     GAsyncReadyCallback _callback_,
                                                     gpointer _user_data_)
{
	DinoUiFreeDesktopNotifierGetConversationIconData* _data_;
	DinoUiFreeDesktopNotifier* _tmp0_;
	DinoEntitiesConversation* _tmp1_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (conversation != NULL);
	_data_ = g_slice_new0 (DinoUiFreeDesktopNotifierGetConversationIconData);
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
	g_task_set_task_data (_data_->_async_result, _data_, dino_ui_free_desktop_notifier_get_conversation_icon_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = _g_object_ref0 (conversation);
	_g_object_unref0 (_data_->conversation);
	_data_->conversation = _tmp1_;
	dino_ui_free_desktop_notifier_get_conversation_icon_co (_data_);
}

static GVariant*
dino_ui_free_desktop_notifier_get_conversation_icon_finish (DinoUiFreeDesktopNotifier* self,
                                                            GAsyncResult* _res_)
{
	GVariant* result;
	DinoUiFreeDesktopNotifierGetConversationIconData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
	result = _data_->result;
	_data_->result = NULL;
	return result;
}

static gpointer
_g_bytes_ref0 (gpointer self)
{
	return self ? g_bytes_ref (self) : NULL;
}

static gboolean
dino_ui_free_desktop_notifier_get_conversation_icon_co (DinoUiFreeDesktopNotifierGetConversationIconData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_tmp0_ = _data_->self->priv->stream_interactor;
	_data_->_tmp1_ = dino_ui_view_model_compat_avatar_picture_model_new (_data_->_tmp0_);
	_data_->_tmp2_ = _data_->_tmp1_;
	_data_->_tmp3_ = dino_ui_view_model_compat_avatar_picture_model_set_conversation (_data_->_tmp2_, _data_->conversation);
	_data_->_tmp4_ = NULL;
	_data_->_tmp4_ = dino_ui_compat_avatar_drawer_new ();
	dino_ui_compat_avatar_drawer_set_model (_data_->_tmp4_, (DinoUiViewModelAvatarPictureModel*) _data_->_tmp3_);
	_g_object_unref0 (_data_->_tmp3_);
	dino_ui_compat_avatar_drawer_set_width_request (_data_->_tmp4_, 40);
	dino_ui_compat_avatar_drawer_set_height_request (_data_->_tmp4_, 40);
	_data_->_tmp5_ = _data_->_tmp4_;
	_g_object_unref0 (_data_->_tmp2_);
	_data_->drawer = _data_->_tmp5_;
	_data_->_tmp6_ = dino_ui_compat_avatar_drawer_draw_image_surface (_data_->drawer);
	_data_->surface = _data_->_tmp6_;
	_data_->_tmp7_ = gdk_pixbuf_get_from_surface (_data_->surface, 0, 0, cairo_image_surface_get_width (_data_->surface), cairo_image_surface_get_height (_data_->surface));
	_data_->avatar = _data_->_tmp7_;
	g_object_get (_data_->avatar, "pixel-bytes", &_data_->_tmp8_, NULL);
	_data_->_tmp9_ = _data_->_tmp8_;
	_data_->bytes = _data_->_tmp9_;
	_data_->_tmp10_ = g_variant_type_new ("ay");
	_data_->_tmp11_ = _data_->_tmp10_;
	_data_->_tmp12_ = 0;
	_data_->_tmp13_ = g_bytes_get_data (_data_->bytes, &_data_->_tmp12_);
	_data_->_tmp14_ = _g_bytes_ref0 (_data_->bytes);
	_data_->_tmp15_ = g_variant_new_from_data (_data_->_tmp11_, _data_->_tmp13_, (gint) _data_->_tmp12_, TRUE, g_bytes_unref, _data_->_tmp14_);
	g_variant_ref_sink (_data_->_tmp15_);
	_data_->_tmp16_ = _data_->_tmp15_;
	_g_variant_type_free0 (_data_->_tmp11_);
	_data_->image_bytes = _data_->_tmp16_;
	_data_->_tmp17_ = gdk_pixbuf_get_width (_data_->avatar);
	_data_->_tmp18_ = _data_->_tmp17_;
	_data_->_tmp19_ = gdk_pixbuf_get_height (_data_->avatar);
	_data_->_tmp20_ = _data_->_tmp19_;
	_data_->_tmp21_ = gdk_pixbuf_get_rowstride (_data_->avatar);
	_data_->_tmp22_ = _data_->_tmp21_;
	_data_->_tmp23_ = gdk_pixbuf_get_has_alpha (_data_->avatar);
	_data_->_tmp24_ = _data_->_tmp23_;
	_data_->_tmp25_ = gdk_pixbuf_get_bits_per_sample (_data_->avatar);
	_data_->_tmp26_ = _data_->_tmp25_;
	_data_->_tmp27_ = gdk_pixbuf_get_n_channels (_data_->avatar);
	_data_->_tmp28_ = _data_->_tmp27_;
	_data_->_tmp29_ = g_variant_new ("(iiibii@ay)", _data_->_tmp18_, _data_->_tmp20_, _data_->_tmp22_, _data_->_tmp24_, _data_->_tmp26_, _data_->_tmp28_, _data_->image_bytes, NULL);
	g_variant_ref_sink (_data_->_tmp29_);
	_data_->result = _data_->_tmp29_;
	_g_variant_unref0 (_data_->image_bytes);
	_g_bytes_unref0 (_data_->bytes);
	_g_object_unref0 (_data_->avatar);
	_cairo_surface_destroy0 (_data_->surface);
	_dino_ui_compat_avatar_drawer_unref0 (_data_->drawer);
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!g_task_get_completed (_data_->_async_result)) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

static void
dino_ui_free_desktop_notifier_add_action_listener (DinoUiFreeDesktopNotifier* self,
                                                   guint32 id,
                                                   const gchar* name,
                                                   DinoUiFreeDesktopNotifierListenerFunc func,
                                                   gpointer func_target,
                                                   GDestroyNotify func_target_destroy_notify)
{
	GeeHashMap* _tmp0_;
	GeeHashMap* _tmp4_;
	gpointer _tmp5_;
	GeeHashMap* _tmp6_;
	DinoUiFreeDesktopNotifierListenerFunc _tmp7_;
	gpointer _tmp7__target;
	GDestroyNotify _tmp7__target_destroy_notify;
	DinoUiFreeDesktopNotifierListenerFuncWrapper* _tmp8_;
	DinoUiFreeDesktopNotifierListenerFuncWrapper* _tmp9_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (name != NULL);
	_tmp0_ = self->priv->action_listeners;
	if (!gee_abstract_map_has_key ((GeeAbstractMap*) _tmp0_, (gpointer) ((guintptr) id))) {
		GeeHashMap* _tmp1_;
		GeeHashMap* _tmp2_;
		GeeHashMap* _tmp3_;
		_tmp1_ = self->priv->action_listeners;
		_tmp2_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, DINO_UI_FREE_DESKTOP_NOTIFIER_TYPE_LISTENER_FUNC_WRAPPER, (GBoxedCopyFunc) dino_ui_free_desktop_notifier_listener_func_wrapper_ref, (GDestroyNotify) dino_ui_free_desktop_notifier_listener_func_wrapper_unref, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
		_tmp3_ = _tmp2_;
		gee_abstract_map_set ((GeeAbstractMap*) _tmp1_, (gpointer) ((guintptr) id), _tmp3_);
		_g_object_unref0 (_tmp3_);
	}
	_tmp4_ = self->priv->action_listeners;
	_tmp5_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp4_, (gpointer) ((guintptr) id));
	_tmp6_ = (GeeHashMap*) _tmp5_;
	_tmp7_ = func;
	_tmp7__target = func_target;
	_tmp7__target_destroy_notify = func_target_destroy_notify;
	func = NULL;
	func_target = NULL;
	func_target_destroy_notify = NULL;
	_tmp8_ = dino_ui_free_desktop_notifier_listener_func_wrapper_new (_tmp7_, _tmp7__target, _tmp7__target_destroy_notify);
	_tmp9_ = _tmp8_;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp6_, name, _tmp9_);
	_dino_ui_free_desktop_notifier_listener_func_wrapper_unref0 (_tmp9_);
	_g_object_unref0 (_tmp6_);
	(func_target_destroy_notify == NULL) ? NULL : (func_target_destroy_notify (func_target), NULL);
	func = NULL;
	func_target = NULL;
	func_target_destroy_notify = NULL;
}

static DinoUiFreeDesktopNotifierListenerFuncWrapper*
dino_ui_free_desktop_notifier_listener_func_wrapper_construct (GType object_type,
                                                               DinoUiFreeDesktopNotifierListenerFunc func,
                                                               gpointer func_target,
                                                               GDestroyNotify func_target_destroy_notify)
{
	DinoUiFreeDesktopNotifierListenerFuncWrapper* self = NULL;
	DinoUiFreeDesktopNotifierListenerFunc _tmp0_;
	gpointer _tmp0__target;
	GDestroyNotify _tmp0__target_destroy_notify;
	self = (DinoUiFreeDesktopNotifierListenerFuncWrapper*) g_type_create_instance (object_type);
	_tmp0_ = func;
	_tmp0__target = func_target;
	_tmp0__target_destroy_notify = func_target_destroy_notify;
	func = NULL;
	func_target = NULL;
	func_target_destroy_notify = NULL;
	(self->func_target_destroy_notify == NULL) ? NULL : (self->func_target_destroy_notify (self->func_target), NULL);
	self->func = NULL;
	self->func_target = NULL;
	self->func_target_destroy_notify = NULL;
	self->func = _tmp0_;
	self->func_target = _tmp0__target;
	self->func_target_destroy_notify = _tmp0__target_destroy_notify;
	(func_target_destroy_notify == NULL) ? NULL : (func_target_destroy_notify (func_target), NULL);
	func = NULL;
	func_target = NULL;
	func_target_destroy_notify = NULL;
	return self;
}

static DinoUiFreeDesktopNotifierListenerFuncWrapper*
dino_ui_free_desktop_notifier_listener_func_wrapper_new (DinoUiFreeDesktopNotifierListenerFunc func,
                                                         gpointer func_target,
                                                         GDestroyNotify func_target_destroy_notify)
{
	return dino_ui_free_desktop_notifier_listener_func_wrapper_construct (DINO_UI_FREE_DESKTOP_NOTIFIER_TYPE_LISTENER_FUNC_WRAPPER, func, func_target, func_target_destroy_notify);
}

static void
dino_ui_free_desktop_notifier_value_listener_func_wrapper_init (GValue* value)
{
	value->data[0].v_pointer = NULL;
}

static void
dino_ui_free_desktop_notifier_value_listener_func_wrapper_free_value (GValue* value)
{
	if (value->data[0].v_pointer) {
		dino_ui_free_desktop_notifier_listener_func_wrapper_unref (value->data[0].v_pointer);
	}
}

static void
dino_ui_free_desktop_notifier_value_listener_func_wrapper_copy_value (const GValue* src_value,
                                                                      GValue* dest_value)
{
	if (src_value->data[0].v_pointer) {
		dest_value->data[0].v_pointer = dino_ui_free_desktop_notifier_listener_func_wrapper_ref (src_value->data[0].v_pointer);
	} else {
		dest_value->data[0].v_pointer = NULL;
	}
}

static gpointer
dino_ui_free_desktop_notifier_value_listener_func_wrapper_peek_pointer (const GValue* value)
{
	return value->data[0].v_pointer;
}

static gchar*
dino_ui_free_desktop_notifier_value_listener_func_wrapper_collect_value (GValue* value,
                                                                         guint n_collect_values,
                                                                         GTypeCValue* collect_values,
                                                                         guint collect_flags)
{
	if (collect_values[0].v_pointer) {
		DinoUiFreeDesktopNotifierListenerFuncWrapper * object;
		object = collect_values[0].v_pointer;
		if (object->parent_instance.g_class == NULL) {
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
		}
		value->data[0].v_pointer = dino_ui_free_desktop_notifier_listener_func_wrapper_ref (object);
	} else {
		value->data[0].v_pointer = NULL;
	}
	return NULL;
}

static gchar*
dino_ui_free_desktop_notifier_value_listener_func_wrapper_lcopy_value (const GValue* value,
                                                                       guint n_collect_values,
                                                                       GTypeCValue* collect_values,
                                                                       guint collect_flags)
{
	DinoUiFreeDesktopNotifierListenerFuncWrapper ** object_p;
	object_p = collect_values[0].v_pointer;
	if (!object_p) {
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
	}
	if (!value->data[0].v_pointer) {
		*object_p = NULL;
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
		*object_p = value->data[0].v_pointer;
	} else {
		*object_p = dino_ui_free_desktop_notifier_listener_func_wrapper_ref (value->data[0].v_pointer);
	}
	return NULL;
}

static GParamSpec*
dino_ui_free_desktop_notifier_param_spec_listener_func_wrapper (const gchar* name,
                                                                const gchar* nick,
                                                                const gchar* blurb,
                                                                GType object_type,
                                                                GParamFlags flags)
{
	DinoUiFreeDesktopNotifierParamSpecListenerFuncWrapper* spec;
	g_return_val_if_fail (g_type_is_a (object_type, DINO_UI_FREE_DESKTOP_NOTIFIER_TYPE_LISTENER_FUNC_WRAPPER), NULL);
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
	G_PARAM_SPEC (spec)->value_type = object_type;
	return G_PARAM_SPEC (spec);
}

static gpointer
dino_ui_free_desktop_notifier_value_get_listener_func_wrapper (const GValue* value)
{
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, DINO_UI_FREE_DESKTOP_NOTIFIER_TYPE_LISTENER_FUNC_WRAPPER), NULL);
	return value->data[0].v_pointer;
}

static void
dino_ui_free_desktop_notifier_value_set_listener_func_wrapper (GValue* value,
                                                               gpointer v_object)
{
	DinoUiFreeDesktopNotifierListenerFuncWrapper * old;
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, DINO_UI_FREE_DESKTOP_NOTIFIER_TYPE_LISTENER_FUNC_WRAPPER));
	old = value->data[0].v_pointer;
	if (v_object) {
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, DINO_UI_FREE_DESKTOP_NOTIFIER_TYPE_LISTENER_FUNC_WRAPPER));
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
		value->data[0].v_pointer = v_object;
		dino_ui_free_desktop_notifier_listener_func_wrapper_ref (value->data[0].v_pointer);
	} else {
		value->data[0].v_pointer = NULL;
	}
	if (old) {
		dino_ui_free_desktop_notifier_listener_func_wrapper_unref (old);
	}
}

static void
dino_ui_free_desktop_notifier_value_take_listener_func_wrapper (GValue* value,
                                                                gpointer v_object)
{
	DinoUiFreeDesktopNotifierListenerFuncWrapper * old;
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, DINO_UI_FREE_DESKTOP_NOTIFIER_TYPE_LISTENER_FUNC_WRAPPER));
	old = value->data[0].v_pointer;
	if (v_object) {
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, DINO_UI_FREE_DESKTOP_NOTIFIER_TYPE_LISTENER_FUNC_WRAPPER));
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
		value->data[0].v_pointer = v_object;
	} else {
		value->data[0].v_pointer = NULL;
	}
	if (old) {
		dino_ui_free_desktop_notifier_listener_func_wrapper_unref (old);
	}
}

static void
dino_ui_free_desktop_notifier_listener_func_wrapper_class_init (DinoUiFreeDesktopNotifierListenerFuncWrapperClass * klass,
                                                                gpointer klass_data)
{
	dino_ui_free_desktop_notifier_listener_func_wrapper_parent_class = g_type_class_peek_parent (klass);
	((DinoUiFreeDesktopNotifierListenerFuncWrapperClass *) klass)->finalize = dino_ui_free_desktop_notifier_listener_func_wrapper_finalize;
}

static void
dino_ui_free_desktop_notifier_listener_func_wrapper_instance_init (DinoUiFreeDesktopNotifierListenerFuncWrapper * self,
                                                                   gpointer klass)
{
	self->ref_count = 1;
}

static void
dino_ui_free_desktop_notifier_listener_func_wrapper_finalize (DinoUiFreeDesktopNotifierListenerFuncWrapper * obj)
{
	DinoUiFreeDesktopNotifierListenerFuncWrapper * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, DINO_UI_FREE_DESKTOP_NOTIFIER_TYPE_LISTENER_FUNC_WRAPPER, DinoUiFreeDesktopNotifierListenerFuncWrapper);
	g_signal_handlers_destroy (self);
	(self->func_target_destroy_notify == NULL) ? NULL : (self->func_target_destroy_notify (self->func_target), NULL);
	self->func = NULL;
	self->func_target = NULL;
	self->func_target_destroy_notify = NULL;
}

static GType
dino_ui_free_desktop_notifier_listener_func_wrapper_get_type_once (void)
{
	static const GTypeValueTable g_define_type_value_table = { dino_ui_free_desktop_notifier_value_listener_func_wrapper_init, dino_ui_free_desktop_notifier_value_listener_func_wrapper_free_value, dino_ui_free_desktop_notifier_value_listener_func_wrapper_copy_value, dino_ui_free_desktop_notifier_value_listener_func_wrapper_peek_pointer, "p", dino_ui_free_desktop_notifier_value_listener_func_wrapper_collect_value, "p", dino_ui_free_desktop_notifier_value_listener_func_wrapper_lcopy_value };
	static const GTypeInfo g_define_type_info = { sizeof (DinoUiFreeDesktopNotifierListenerFuncWrapperClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) dino_ui_free_desktop_notifier_listener_func_wrapper_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DinoUiFreeDesktopNotifierListenerFuncWrapper), 0, (GInstanceInitFunc) dino_ui_free_desktop_notifier_listener_func_wrapper_instance_init, &g_define_type_value_table };
	static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
	GType dino_ui_free_desktop_notifier_listener_func_wrapper_type_id;
	dino_ui_free_desktop_notifier_listener_func_wrapper_type_id = g_type_register_fundamental (g_type_fundamental_next (), "DinoUiFreeDesktopNotifierListenerFuncWrapper", &g_define_type_info, &g_define_type_fundamental_info, 0);
	return dino_ui_free_desktop_notifier_listener_func_wrapper_type_id;
}

static GType
dino_ui_free_desktop_notifier_listener_func_wrapper_get_type (void)
{
	static volatile gsize dino_ui_free_desktop_notifier_listener_func_wrapper_type_id__once = 0;
	if (g_once_init_enter (&dino_ui_free_desktop_notifier_listener_func_wrapper_type_id__once)) {
		GType dino_ui_free_desktop_notifier_listener_func_wrapper_type_id;
		dino_ui_free_desktop_notifier_listener_func_wrapper_type_id = dino_ui_free_desktop_notifier_listener_func_wrapper_get_type_once ();
		g_once_init_leave (&dino_ui_free_desktop_notifier_listener_func_wrapper_type_id__once, dino_ui_free_desktop_notifier_listener_func_wrapper_type_id);
	}
	return dino_ui_free_desktop_notifier_listener_func_wrapper_type_id__once;
}

static gpointer
dino_ui_free_desktop_notifier_listener_func_wrapper_ref (gpointer instance)
{
	DinoUiFreeDesktopNotifierListenerFuncWrapper * self;
	self = instance;
	g_atomic_int_inc (&self->ref_count);
	return instance;
}

static void
dino_ui_free_desktop_notifier_listener_func_wrapper_unref (gpointer instance)
{
	DinoUiFreeDesktopNotifierListenerFuncWrapper * self;
	self = instance;
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
		DINO_UI_FREE_DESKTOP_NOTIFIER_LISTENER_FUNC_WRAPPER_GET_CLASS (self)->finalize (self);
		g_type_free_instance ((GTypeInstance *) self);
	}
}

static void
dino_ui_free_desktop_notifier_class_init (DinoUiFreeDesktopNotifierClass * klass,
                                          gpointer klass_data)
{
	dino_ui_free_desktop_notifier_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &DinoUiFreeDesktopNotifier_private_offset);
	G_OBJECT_CLASS (klass)->finalize = dino_ui_free_desktop_notifier_finalize;
	dino_ui_free_desktop_notifier_signals[DINO_UI_FREE_DESKTOP_NOTIFIER_CONVERSATION_SELECTED_SIGNAL] = g_signal_new ("conversation-selected", DINO_UI_TYPE_FREE_DESKTOP_NOTIFIER, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, DINO_ENTITIES_TYPE_CONVERSATION);
}

static void
dino_ui_free_desktop_notifier_dino_notification_provider_interface_init (DinoNotificationProviderIface * iface,
                                                                         gpointer iface_data)
{
	dino_ui_free_desktop_notifier_dino_notification_provider_parent_iface = g_type_interface_peek_parent (iface);
	iface->get_priority = (gdouble (*) (DinoNotificationProvider*)) dino_ui_free_desktop_notifier_real_get_priority;
	iface->notify_message = (void (*) (DinoNotificationProvider*, DinoEntitiesMessage*, DinoEntitiesConversation*, const gchar*, const gchar*, GAsyncReadyCallback, gpointer)) dino_ui_free_desktop_notifier_real_notify_message;
	iface->notify_message_finish = (void (*) (DinoNotificationProvider*, GAsyncResult*)) dino_ui_free_desktop_notifier_notify_message_finish;
	iface->notify_file = (void (*) (DinoNotificationProvider*, DinoEntitiesFileTransfer*, DinoEntitiesConversation*, gboolean, const gchar*, const gchar*, GAsyncReadyCallback, gpointer)) dino_ui_free_desktop_notifier_real_notify_file;
	iface->notify_file_finish = (void (*) (DinoNotificationProvider*, GAsyncResult*)) dino_ui_free_desktop_notifier_notify_file_finish;
	iface->notify_call = (void (*) (DinoNotificationProvider*, DinoEntitiesCall*, DinoEntitiesConversation*, gboolean, gboolean, const gchar*, GAsyncReadyCallback, gpointer)) dino_ui_free_desktop_notifier_real_notify_call;
	iface->notify_call_finish = (void (*) (DinoNotificationProvider*, GAsyncResult*)) dino_ui_free_desktop_notifier_notify_call_finish;
	iface->retract_call_notification = (void (*) (DinoNotificationProvider*, DinoEntitiesCall*, DinoEntitiesConversation*, GAsyncReadyCallback, gpointer)) dino_ui_free_desktop_notifier_real_retract_call_notification;
	iface->retract_call_notification_finish = (void (*) (DinoNotificationProvider*, GAsyncResult*)) dino_ui_free_desktop_notifier_retract_call_notification_finish;
	iface->notify_subscription_request = (void (*) (DinoNotificationProvider*, DinoEntitiesConversation*, GAsyncReadyCallback, gpointer)) dino_ui_free_desktop_notifier_real_notify_subscription_request;
	iface->notify_subscription_request_finish = (void (*) (DinoNotificationProvider*, GAsyncResult*)) dino_ui_free_desktop_notifier_notify_subscription_request_finish;
	iface->notify_connection_error = (void (*) (DinoNotificationProvider*, DinoEntitiesAccount*, DinoConnectionManagerConnectionError*, GAsyncReadyCallback, gpointer)) dino_ui_free_desktop_notifier_real_notify_connection_error;
	iface->notify_connection_error_finish = (void (*) (DinoNotificationProvider*, GAsyncResult*)) dino_ui_free_desktop_notifier_notify_connection_error_finish;
	iface->notify_muc_invite = (void (*) (DinoNotificationProvider*, DinoEntitiesAccount*, XmppJid*, XmppJid*, const gchar*, GAsyncReadyCallback, gpointer)) dino_ui_free_desktop_notifier_real_notify_muc_invite;
	iface->notify_muc_invite_finish = (void (*) (DinoNotificationProvider*, GAsyncResult*)) dino_ui_free_desktop_notifier_notify_muc_invite_finish;
	iface->notify_voice_request = (void (*) (DinoNotificationProvider*, DinoEntitiesConversation*, XmppJid*, GAsyncReadyCallback, gpointer)) dino_ui_free_desktop_notifier_real_notify_voice_request;
	iface->notify_voice_request_finish = (void (*) (DinoNotificationProvider*, GAsyncResult*)) dino_ui_free_desktop_notifier_notify_voice_request_finish;
	iface->retract_content_item_notifications = (void (*) (DinoNotificationProvider*, GAsyncReadyCallback, gpointer)) dino_ui_free_desktop_notifier_real_retract_content_item_notifications;
	iface->retract_content_item_notifications_finish = (void (*) (DinoNotificationProvider*, GAsyncResult*)) dino_ui_free_desktop_notifier_retract_content_item_notifications_finish;
	iface->retract_conversation_notifications = (void (*) (DinoNotificationProvider*, DinoEntitiesConversation*, GAsyncReadyCallback, gpointer)) dino_ui_free_desktop_notifier_real_retract_conversation_notifications;
	iface->retract_conversation_notifications_finish = (void (*) (DinoNotificationProvider*, GAsyncResult*)) dino_ui_free_desktop_notifier_retract_conversation_notifications_finish;
}

static void
dino_ui_free_desktop_notifier_instance_init (DinoUiFreeDesktopNotifier * self,
                                             gpointer klass)
{
	GeeHashMap* _tmp0_;
	GeeHashMap* _tmp1_;
	GeeHashMap* _tmp2_;
	GeeHashMap* _tmp3_;
	self->priv = dino_ui_free_desktop_notifier_get_instance_private (self);
	self->priv->supports_body_markup = FALSE;
	self->priv->supports_body_hyperlinks = FALSE;
	_tmp0_ = gee_hash_map_new (DINO_ENTITIES_TYPE_CONVERSATION, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, G_TYPE_UINT, NULL, NULL, _dino_entities_conversation_hash_func_gee_hash_data_func, NULL, NULL, _dino_entities_conversation_equals_func_gee_equal_data_func, NULL, NULL, NULL, NULL, NULL);
	self->priv->content_notifications = _tmp0_;
	_tmp1_ = gee_hash_map_new (DINO_ENTITIES_TYPE_CONVERSATION, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, GEE_TYPE_LIST, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, _dino_entities_conversation_hash_func_gee_hash_data_func, NULL, NULL, _dino_entities_conversation_equals_func_gee_equal_data_func, NULL, NULL, NULL, NULL, NULL);
	self->priv->conversation_notifications = _tmp1_;
	_tmp2_ = gee_hash_map_new (G_TYPE_UINT, NULL, NULL, GEE_TYPE_HASH_MAP, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
	self->priv->action_listeners = _tmp2_;
	_tmp3_ = gee_hash_map_new (DINO_ENTITIES_TYPE_CALL, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, G_TYPE_UINT, NULL, NULL, _dino_entities_call_hash_func_gee_hash_data_func, NULL, NULL, _dino_entities_call_equals_func_gee_equal_data_func, NULL, NULL, NULL, NULL, NULL);
	self->priv->call_notifications = _tmp3_;
}

static void
dino_ui_free_desktop_notifier_finalize (GObject * obj)
{
	DinoUiFreeDesktopNotifier * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, DINO_UI_TYPE_FREE_DESKTOP_NOTIFIER, DinoUiFreeDesktopNotifier);
	_g_object_unref0 (self->priv->stream_interactor);
	_g_object_unref0 (self->priv->dbus_notifications);
	_g_object_unref0 (self->priv->content_notifications);
	_g_object_unref0 (self->priv->conversation_notifications);
	_g_object_unref0 (self->priv->action_listeners);
	_g_object_unref0 (self->priv->call_notifications);
	G_OBJECT_CLASS (dino_ui_free_desktop_notifier_parent_class)->finalize (obj);
}

static GType
dino_ui_free_desktop_notifier_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (DinoUiFreeDesktopNotifierClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) dino_ui_free_desktop_notifier_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DinoUiFreeDesktopNotifier), 0, (GInstanceInitFunc) dino_ui_free_desktop_notifier_instance_init, NULL };
	static const GInterfaceInfo dino_notification_provider_info = { (GInterfaceInitFunc) dino_ui_free_desktop_notifier_dino_notification_provider_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	GType dino_ui_free_desktop_notifier_type_id;
	dino_ui_free_desktop_notifier_type_id = g_type_register_static (G_TYPE_OBJECT, "DinoUiFreeDesktopNotifier", &g_define_type_info, 0);
	g_type_add_interface_static (dino_ui_free_desktop_notifier_type_id, DINO_TYPE_NOTIFICATION_PROVIDER, &dino_notification_provider_info);
	DinoUiFreeDesktopNotifier_private_offset = g_type_add_instance_private (dino_ui_free_desktop_notifier_type_id, sizeof (DinoUiFreeDesktopNotifierPrivate));
	return dino_ui_free_desktop_notifier_type_id;
}

GType
dino_ui_free_desktop_notifier_get_type (void)
{
	static volatile gsize dino_ui_free_desktop_notifier_type_id__once = 0;
	if (g_once_init_enter (&dino_ui_free_desktop_notifier_type_id__once)) {
		GType dino_ui_free_desktop_notifier_type_id;
		dino_ui_free_desktop_notifier_type_id = dino_ui_free_desktop_notifier_get_type_once ();
		g_once_init_leave (&dino_ui_free_desktop_notifier_type_id__once, dino_ui_free_desktop_notifier_type_id);
	}
	return dino_ui_free_desktop_notifier_type_id__once;
}

static void
_vala_array_destroy (gpointer array,
                     gssize array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		gssize i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gssize array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}

static inline gpointer
_vala_memdup2 (gconstpointer mem,
               gsize byte_size)
{
	gpointer new_mem;
	if (mem && byte_size != 0) {
		new_mem = g_malloc (byte_size);
		memcpy (new_mem, mem, byte_size);
	} else {
		new_mem = NULL;
	}
	return new_mem;
}

